<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme Mediasmack AMP for publication on WordPress.org
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 *
 * Depending on your implementation, you may want to change the include call:
 *
 * Parent Theme:
 * require_once get_template_directory() . '/path/to/class-tgm-plugin-activation.php';
 *
 * Child Theme:
 * require_once get_stylesheet_directory() . '/path/to/class-tgm-plugin-activation.php';
 *
 * Plugin:
 * require_once dirname( __FILE__ ) . '/path/to/class-tgm-plugin-activation.php';
 */
require_once get_template_directory() . '/inc/plugins/class-tgm-plugin-activation.php';


add_action( 'tgmpa_register', 'register_required_plugins' );

// This function is called from the above hook
function register_required_plugins()
{
	// The plugins array allows us to define multiple plugins we want to include.
	// The commented out example shows how we can include and activation a bundled
	// plugin zip file in our theme.
	$plugins = array(
		array(
			'name'               => 'Advanced Custom Fields Pro',
			'slug'               => 'advanced-custom-fields',
			'source'             => get_template_directory() . '\inc\plugins\advanced-custom-fields-pro.zip',
			'required'           => true,
			'version'            => '',
			'force_activation'   => false,
			'force_deactivation' => false,
            'external_url'       => '',
		),

        array(
			'name'               => 'ACF Extended Pro',
			'slug'               => 'ACF Extended Pro',
			'source'             => get_template_directory() . '\inc\plugins\acf-extended-pro.zip',
			'required'           => true,
			'version'            => '',
			'force_activation'   => false,
			'force_deactivation' => false,
            'external_url'       => '',
		),

		// This below definition will include the ACF plugin from the Wordpress.org plugins repository
		// and if permissions permit, will allow for it to be automatically downloaded and installed.
		// If permissions don't allow, the user will be prompted into downloading the plugin themselves
		// and installing it manually.

		array(
			'name'      		=> 'Akismet Spam Protection',
			'slug'      		=> 'akismet',
			'required'  		=> true,
			'force_activation'	=> false,
        ),

        array(
			'name'      		=> 'Better Search Replace',
			'slug'      		=> 'better-search-replace',
			'required'  		=> true,
			'force_activation'	=> false,
        ),

        array(
			'name'      		=> 'Category Order and Taxonomy Terms Order',
			'slug'      		=> 'taxonomy-terms-order',
			'required'  		=> true,
			'force_activation'	=> false,
        ),

        array(
			'name'      		=> 'Enable Media Replace',
			'slug'      		=> 'enable-media-replace',
			'required'  		=> true,
			'force_activation'	=> false,
        ),
		
		array(
			'name'      		=> 'Post Type Switcher',
			'slug'      		=> 'post-type-switcher',
			'required'  		=> true,
			'force_activation'	=> false,
        ),

        array(
			'name'      		=> 'Redirection',
			'slug'      		=> 'redirection',
			'required'  		=> true,
			'force_activation'	=> false,
        ),

		array(
			'name'      		=> 'Regenerate Thumbnails Advanced',
			'slug'      		=> 'regenerate-thumbnails-advanced',
			'required'  		=> true,
			'force_activation'	=> false,
        ),
		
		array(
			'name'      		=> 'Simple Page Ordering',
			'slug'      		=> 'simple-page-ordering',
			'required'  		=> true,
			'force_activation'	=> false,
        ),

        array(
			'name'      		=> 'Thumbs Rating',
			'slug'      		=> 'thumbs-rating',
			'required'  		=> true,
			'force_activation'	=> false,
        ),

        array(
			'name'      		=> 'Yoast SEO',
			'slug'      		=> 'wordpress-seo',
			'required'  		=> true,
			'force_activation'	=> false,
		),
	);

	$theme_text_domain = 'wp';

	$config = array(
		'domain'       		=> $theme_text_domain,
		'default_path' 		=> '',
		'parent_menu_slug' 	=> 'themes.php',
		'parent_url_slug' 	=> 'themes.php',
		'menu'         		=> 'install-required-plugins',
		'has_notices'      	=> true,
		'is_automatic'    	=> false,
		'message' 			=> '',
		'strings'      		=> array(
			'page_title'                       			=> __( 'Install Required Plugins', $theme_text_domain ),
			'menu_title'                       			=> __( 'Install Plugins', $theme_text_domain ),
			'installing'                       			=> __( 'Installing Plugin: %s', $theme_text_domain ), // %1$s = plugin name
			'oops'                             			=> __( 'Something went wrong with the plugin API.', $theme_text_domain ),
			'notice_can_install_required'     			=> _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_install_recommended'			=> _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_install'  					=> _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s)
			'notice_can_activate_required'    			=> _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
			'notice_can_activate_recommended'			=> _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_activate' 					=> _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s)
			'notice_ask_to_update' 						=> _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s)
			'notice_cannot_update' 						=> _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s)
			'install_link' 					  			=> _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
			'activate_link' 				  			=> _n_noop( 'Activate installed plugin', 'Activate installed plugins' ),
			'return'                           			=> __( 'Return to Required Plugins Installer', $theme_text_domain ),
			'plugin_activated'                 			=> __( 'Plugin activated successfully.', $theme_text_domain ),
			'complete' 									=> __( 'All plugins installed and activated successfully. %s', $theme_text_domain ), // %1$s = dashboard link
			'nag_type'									=> 'updated' // Determines admin notice type - can only be 'updated' or 'error'
		)
	);

	tgmpa( $plugins, $config );
}