<?php
/**
 * Template Name: Sitemap
 * The template for displaying the sitemap
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

get_header();
?>
<style>
#sitemap ul {
	margin: 10px 0px
}
#sitemap li {
	list-style-type: none;
	margin: 0px;
}
#sitemap li:hover{
	background: #ffffff;
}
#sitemap li a{
	color: #00000090;
	display: block;
	padding: 5px 15px;
	width: 100%;
}
#sitemap li a:hover{
	color: #000000;
}
</style>
<div id="main-container" class="content-area">
	<section>
		<div class="container grid-xl">
			<div class="columns">
				<div class="column col-12">
					<?php if(!is_front_page()): ?>
						<?php get_breadcrumb(); ?>
					<?php endif; ?>
				</div>
			</div>
		</div>
	</section>
	<?php if (has_post_thumbnail( $post->ID ) ): ?>
		<div id="featuredImage">
			<?php 
			$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'header-banner' );
			$thumbnail_id = get_post_thumbnail_id( $post->ID );
			$alt = get_post_meta($thumbnail_id, '_wp_attachment_image_alt', true); 
			?>
			<div class="fixed-container">
				<amp-img 
					alt="<?php echo $alt; ?>"
					class="contain"
					layout="fill"
					src="<?php echo $image[0]; ?>"></amp-img>
			</div>
		</div>
	<?php endif; ?>
	<section>
		<div class="container grid-xl p-relative">
			<div class="columns">
				<div class="column col-12 my-layout">
					<article>
						<div class="columns">
							<div class="column col-12 col-xl-12 ">
								<main id="main" class="site-main">
									<div class="columns">
										<div class="column col-6 col-md-12 col-mx-auto large">
											<h1><?php echo get_bloginfo('name'); ?> Sitemap</h1>
											<?php the_content();?>
										</div>
									</div>
								</main>
							</div>
						</div>
					</article>
				</div>
			</div>
		</div>
	</section>
	<section id="sitemap" class="bg-gray-light py-layout">
		<div class="container grid-xl">
			<div class="columns">
				<div class="column col-3 col-lg-4 col-md-6 col-sm-12 my-layout">
					<strong class="large">Pages</strong>
					<div class="divider"></div>
					<ul>
						<?php wp_list_pages( 'exclude=28,48&sort_column=menu_order&title_li=' ); ?>
					</ul>
				</div>
				<?php foreach( get_post_types( array('public' => true, '_builtin' => false) ) as $post_type ) {
					//Retrieves an object which describes any registered post type: 
					//in this case only user-created Custom Post TypeS
					$cpt = get_post_type_object( $post_type );
					echo '<div class="column col-3 col-lg-4 col-md-6 col-sm-12 my-layout">';
					echo '<strong class="large">'.$cpt->labels->name.'</strong>';
					echo '<div class="divider"></div>';
					echo '<ul>';
					
					$args = array(
						'post_type' => $post_type,
						'post__not_in' => array(), /**Exclude custom posts by ID separated by comma inside the array.**/
						'posts_per_page' => -1  //show all custom posts
					);
					$query_cpt = new WP_Query($args);
					
					while( $query_cpt->have_posts() ) {
						$query_cpt->the_post();
						echo '<li><a title="'.get_the_title().'" href="'.get_permalink().'">'.get_the_title().'</a></li>';
					}
					echo '</ul>';
					echo '</div>';
					} 
				?> 
				<?php 
				$args = array(
					'post_type'=> 'post',
					'orderby'    => 'ID',
					'post_status' => 'publish',
					'order'    => 'DESC',
					'posts_per_page' => -1,
					);
				$result = new WP_Query( $args );
				if ( $result-> have_posts() ) : ?>
					<div class="column col-12 my-layout">
						<strong class="large">Posts</strong>
						<div class="divider"></div>
							<ul>
								<div class="columns">
									<?php while ( $result->have_posts() ) : $result->the_post(); ?>
										<div class="column col-3 col-lg-4 col-md-6 col-sm-12">
											<li>
												<a href="<?php the_permalink();?>"><?php the_title(); ?></a>
											</li>
										</div>
									<?php endwhile; ?>
								</div>
							</ul>
						</div>
					</div>
				<?php endif; 
				wp_reset_postdata(); ?>
			</div>
		</div>
	<section>
</div>

<?php

get_footer();
