<?php
/**
 * Template part for displaying content on posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

if (has_post_thumbnail( $post->ID )) {
	$featuredImage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'header-banner' );
	$thumbnail_id = get_post_thumbnail_id( $post->ID );
	$alt = get_post_meta($thumbnail_id, '_wp_attachment_image_alt', true);
}
$lead = get_field('lead');
$authorID = get_the_author_meta('ID');
$avatar = get_field('avatar', 'user_' . $authorID);
$size = "thumbnail";
$image = wp_get_attachment_image_src( $avatar, $size );
$pageLink = get_field('pageLinkTeam', 'user_' . $authorID);
?>
<style>
    /* Post - Share */
    #author {
        position: sticky;
        top: <?php the_field('headerHeight', 'option');
        ?>px;
        margin-top: 1rem
    }

    #featuredImage {
        z-index: 2;
        max-height: 40vh;
    }

    #share i {
        border-radius: 0rem;
        display: inline-block;
        color: <?php the_field('colorGray', 'option');
        ?>;
        font-size: 1rem;
        padding: 1rem 1.5rem;
        text-align: center;
        transition: .1s;
    }

    article.post main,
    article.post footer {
        margin-left: 0rem;
        margin-right: 0rem;
    }

    div#share {
        text-align: center;
    }

    /* Comments */
    label {
        display: block;
    }
</style>

<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
    <div class="row mb-5">
        <div id="featuredImage" class="col-12 bg-gray">
            <?php if (has_post_thumbnail( $post->ID ) ): ?>
            <img alt="<?php echo $alt; ?>" class="img-fluid" src="<?php echo $featuredImage[0]; ?>"
                style="height:100%;width:100%;object-fit:cover;">
            <?php endif; ?>
        </div>
    </div>
    <div class="container grid-xl mb-5">
        <div class="row justify-content-center">
            <div class="col-12 col-md-10 col-lg-8 col-xl-7">
                <h1 class="entry-title display-5 text-center"><?php the_title(); ?></h1>
                <div class="lead text-center">
                    <?php echo $lead ;?>
                </div>
                <div class="col-12 my-5">
                    <hr>
                    <div class="row align-items-center justify-content-center text-center g-0">
                        <div class="col-auto text-start mt-2 mb-2 ">
                            <?php if($avatar):?>
                                <?php if($pageLink):?>
                                    <a href="<?php echo $pageLink ;?>">
                                        <img alt="<?php the_author();?> Avatar" class="avatar avatar-lg me-2"
                                    src="<?php echo $image[0];?>">
                                    </a>
                                <?php else:?>
                                    <img alt="<?php the_author();?> Avatar" class="avatar avatar-lg me-2" src="<?php echo $image[0];?>">
                                <?php endif;?>
                            <?php endif;?>
                        </div>
                        <div class="col text-start">
                            <div class="small align-middle">
                                <div class="text-dark fw-bold">
                                    <?php the_author();?>
                                </div>
                                <div class="text-muted">
                                    <?php 
                                    $post_date = get_the_date( 'Y' );
                                    if(get_the_modified_time('Y') != $post_date):?>
                                    Updated on <?php the_modified_time('Y'); ?>
                                    <?php else:?>
                                    Published on <?php the_date('F j, Y');?>
                                    <?php endif;?>
                                </div>
                            </div>
                        </div>
                        <div class="col-auto text-end">
                            <?php if($pageLink):?>
                                <a class="btn btn-sm mt-1 btn-dark" href="<?php echo $pageLink ;?>">About</a>
                            <?php endif;?>
                            <a class="btn btn-sm btn-primary mt-1"
                            href="<?php echo get_post_type_archive_link("contact")?>">Contact</a>
                        </div>
                    </div>
                    <hr>
                </div>
                <div id="content" class="mb-5">
                    <?php
					if ( 'post' === get_post_type() ) :
						?>
                    <?php endif; ?>
                    <?php
				the_content( sprintf(
					wp_kses(
						/* translators: %s: Name of current post. Only visible to screen readers */
						__( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'amp' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				) );

			//	wp_link_pages( array(
			//		'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'amp' ),
			//		'after'  => '</div>',
			//	) );
			?>
                </div>
            </div>
            <div class="row justify-content-center">
                <div class="col-12 col-md-10 col-lg-8 col-xl-7">
                    <div class="row">
                        <div id="share" class="col-12 col-md text-center mt-layout mb-3">
                            <h2 class="lead">Share</h2>
                            <div id="share">
                                <a class="btn btn-light"
                                    href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink();?>&quote=<?php the_title(); ?>"
                                    title="Share on Facebook" target="_blank">
                                    <span class="icon-facebook"></span>
                                </a>
                                <a class="btn btn-light" target="_new"
                                    href="https://twitter.com/intent/tweet?text=<?php echo urlencode(substr(get_the_title(), 0, 79));?>&url= <?php echo urlencode(get_permalink());?>">
                                    <span class="icon-twitter"></span>
                                </a>
                                <a class="btn btn-light"
                                    href="http://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink();?>&title=<?php the_title();?>"
                                    target="_blank" title="Share on LinkedIn">
                                    <span class="icon-linkedin"></span>
                                </a>
                                <a class="btn btn-light"
                                    href="mailto:?subject=<<?php the_title();?>>&body=<<?php the_permalink();?>>"
                                    target="_blank">
                                    <span class="icon-envelope-o"></span>
                                </a>
                            </div>
                        </div>
                        <div id="comments" class="col-12 col-md text-center">
                            <h2 class="lead">Comment</h2>
                            <!-- Button trigger modal -->
                            <button type="button" class="btn btn-gray" data-toggle="modal" data-target="#comment">
                                <i class="fas fa-comment"></i> Comment
                            </button>

                            <div class="modal fade" id="comment" tabindex="-1" role="dialog"
                                aria-labelledby="commentLabel" aria-hidden="true">
                                <div class="modal-dialog" role="document">
                                    <div class="modal-content">
                                        <div class="modal-header">
                                            <h5 class="modal-title" id="exampleModalLabel"><?php comments_number();?>
                                            </h5>
                                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                                <span aria-hidden="true">&times;</span>
                                            </button>
                                        </div>
                                        <div class="modal-body">
                                            <?php
									// If comments are open or we have at least one comment, load up the comment template.
									if ( comments_open() || get_comments_number() ) :
										comments_template();
									endif;
								;?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
</article><!-- #post-<?php the_ID(); ?> -->