<?php
/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package amp
 */

$logoDark = get_field('logo_dark', 'option');
$footerText = get_field('footer_text', 'option');
$liveChat = get_field('components_live_chat', 'option');
$privacy = get_template_page_url('privacy-policy.php');
$terms = get_template_page_url('terms.php');
$cookie = get_template_page_url('cookie-policy.php');
$sitemap = get_template_page_url('sitemap.php');
$agencyCredit = get_field('agency_credit','option');
?>
<style>
    #footer-logo {
        max-width: 200px;
    }

    footer a {
        color: var(--gray-color-light);
    }

    footer a:hover {
        color: var(--gray-color-light-hover);
    }

    .footerMenu {
        list-style: none;
        padding: 0px
    }
</style>
</div><!-- #content -->
<footer class="site-footer bg-dark">
    <div id="footer-top" class="py-5">
        <div class="container grid-xl">
            <div class="row gx-3">
                <div class="col-12 col-md-6 col-lg-3 mb-4">
                    <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                        <?php if( !empty( $logoDark ) ): ?>
                        <img id="footer-logo" class="pb-3" alt="<?php bloginfo('name'); ?>"
                            src="<?php echo esc_url($logoDark['url']); ?>" layout="fill" width="100%">
                        <?php else: ?>
                        <a class="site-title navbar-item large" href="/" rel="home"><?php bloginfo('name'); ?></a>
                        <?php endif ; ?>
                    </a>
                    <?php if($footerText != "0"):?>
                    <p class="text-light">
                        <?php echo $footerText;?>
                    </p>
                    <?php else:?>
                    <p class="text-light">
                        <?php the_field ('footer_text_custom','option');?>
                    </p>
                    <?php endif;?>
                </div>
                <div class="col-12 col-md-6 col-lg-3 mb-4">
                    <div class="row">
                        <div class="col-12">
                            <p class="text-light text-uppercase">
                                Contact
                            </p>
                        </div>
                    </div>
                    <div class="row align-items-center">
                        <div class="col-12">
                            <div class="row">
                                <div class="col-auto text-center text-light">
                                    <span class="icon-phone me-1"></span>
                                </div>
                                <div class="col">
                                    <?php echo do_shortcode('[phone]') ;?>
                                </div>
                                <div class="col-12">
                                    <hr class="my-3">
                                    <div class="row">
                                        <div class="col-auto text-center text-light">
                                            <span class="icon-map-marker me-2"></span>
                                        </div>
                                        <div class="col">
                                            <?php echo do_shortcode('[address]');?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-12">
                                    <hr class="my-3">
                                    <div class="row">
                                        <div class="col-auto text-center text-light">
                                            <span class="icon-envelope"></span>
                                        </div>
                                        <div class="col">
                                            <?php echo do_shortcode('[email]');?>
                                        </div>
                                    </div>
                                </div>
                                <?php if($liveChat):?>
                                <div class="col-12">
                                    <hr class="my-3">
                                    <div class="row">
                                        <div class="col-auto text-center text-light">
                                            <span class="icon-comments"></span>
                                        </div>
                                        <div class="col">
                                            <a class="btn btn-sm btn-success mt-2" href="#"> Live Chat</a>
                                        </div>
                                    </div>
                                </div>
                                <?php endif ;?>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-12 col-md-6 col-lg-3 mb-4">
                    <p class="text-light text-uppercase">
                        Useful Links
                    </p>
                    <?php
						wp_nav_menu( array(
							'theme_location'    => 'primary',
							'container'         => '',
							'menu_class'        => 'footerMenu',
							'depth'				=> 1,
						) );
					?>
                </div>
                <div class="col-12 col-md-6 col-lg-3 mb-4">
                    <p class="text-light text-uppercase">
                        Social
                    </p>
                    <div id="socialMedia" class="mb-4">
                        <?php  
                        if ( have_rows('social_media', 'option')):?>
                        <?php while(have_rows('social_media', 'option')) : the_row();
                            $field = get_sub_field('account');
                            ?>
                        <a class="btn btn-dark text-light" href="<?php the_sub_field('url')?>" target="_blank">
                            <span class="<?php echo $field['value'];?> pr-2"></span>
                        </a>
                        <?php endwhile;?>
                        <?php endif; ?>
                    </div>
                    <p class="text-light text-uppercase">
                        Subscribe
                    </p>
                    <?php echo do_shortcode('[newsletter_form form="1"]');?>
                    <small class="text-muted">By subscribing you agree to the <a href="<?php echo $privacyPolicy;?>"
                            target="_blank">Privacy Policy</a></small>
                </div>
            </div>
        </div>
    </div>
    <div id="footer-bottom" class="p-3">
        <div class="container grid-xl">
            <div class="row gx-5 align-items-center">
                <div class="col text-light small">
                    © <?php echo date("Y"); ?> <?php the_field('name','option'); ?> All Right Reserved.
                    | <a href="<?php echo $privacy ?>" target="_blank">Privacy Policy</a> |
                    <a href="<?php echo $cookie ?>" target="_blank">Cookie Policy</a> |
                    <a href="<?php echo $terms ?>" target="_blank">Terms</a> |
                    <a href="<?php echo $sitemap ?>" target="_blank">Sitemap</a>
                </div>
                <div class="col-auto text-end">
                    <?php if($agencyCredit != "none" ):?>
                    <?php include get_template_directory() . '/components/help-desk/help-desk.php' ;?>
                    <?php endif;?>
                </div>
            </div>
        </div>
    </div>
    <!-- Search Modal -->
    <div class="modal modal-small fade" id="searchModal" tabindex="-1" role="dialog"
        aria-labelledby="#searchModal" aria-hidden="true">
        <div class="modal-dialog modal-sm" role="document">
            <div class="modal-content">
                <div class="container p-2">
                    <form role="search" method="get" class="form search-form " action="<?php echo home_url( '/' ); ?>">
                        <div class="input-group">
                            <input name="s" type="text" class="form-control form-control-lg"
                                placeholder="Search the site">
                            <span class="input-group-btn">
                                <button type="submit" value="" name="search" id="search" class="btn btn-primary btn-lg" type="button">
                                    <span class="icon-search" aria-hidden="true"></span>&nbsp;</button>
                            </span>
                        </div>
                    </form>
                    <small class="text-light">Hit enter to search or ESC to close</small>
                </div>
            </div>
        </div>
    </div>
</footer>

<script>
    // Get Header Height
    // NOTES
    // Need this here but don't know why.
    var h = document.getElementById('header').clientHeight;
    document.getElementById("content").style.margin = h + 'px 0px 0px 0px';
</script>
<!-- #page -->
</body>

</html>