<?php
/**
 * Template part for displaying posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

?>
<style>
/* Post - Share */
#author {
	position: sticky;
	top: <?php the_field('headerHeight', 'option');?>px;
	margin-top: 1rem
}
#featuredImage {
	z-index: 2;
}
#share i {
  border-radius: 0rem;
  display: inline-block;
  color: <?php the_field('colorGray', 'option') ;?>;
  font-size: 1rem;
  padding: 1rem 1.5rem;
  text-align: center;
  transition: .1s;
}

article.post main, article.post footer {
  margin-left: 0rem;
  margin-right: 0rem;
}

@media only screen and (min-width: 1000px) {
	@keyframes slideInFromBottom {
		0% {
			transform: translateY(30px);
			opacity: 0%;
		}
		100% {
			transform: translateY(0);
			opacity:100%;
		}
	}
	article.post {
		animation: .5s ease-out 0s 1 slideInFromBottom;
	}
	#share {  
		animation: .8s ease-out 0s 1 slideInFromRight;
	}
	article.post  {
		display: flex;
		display: -ms-flexbox;
		-ms-flex-direction: column;
		flex-direction: column;
	}
}
div#authorContainer, div#shareContainer {
    margin-left: auto;
	margin-right: auto;
}
div#share {
    text-align: center;
}
</style>
<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
	<div id="featuredImage" class="column col-12 px-0">
		<?php if (has_post_thumbnail( $post->ID ) ): ?>
			<?php 
			$featuredImage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'header-banner' );
			$thumbnail_id = get_post_thumbnail_id( $post->ID );
			$alt = get_post_meta($thumbnail_id, '_wp_attachment_image_alt', true); 
			?>
			<div class="fixed-container">
				<amp-img 
					alt="<?php echo $alt; ?>"
					class="contain"
					layout="fill"
					src="<?php echo $featuredImage[0]; ?>"></amp-img>
			</div>
		<?php endif; ?>
	</div>
	<div class="container grid-xl p-relative">
		<div class="columns">
			<div class="column col-2"></div>
			<div class="column col-8 col-lg-12">
				<main id="main" class="site-main entry-content mt-layout">
					<h1 class="entry-title"><?php the_title(); ?></h1>
					<div id="posted-details">
						<?php 
						$post_date = get_the_date( 'Y' );
						if(get_the_modified_time('Y') != $post_date):?>
							<span class="chip bg-primary">Updated <?php the_modified_time('Y'); ?></span>
						<?php endif;?>
						<?php	
							amp_posted_on();
							amp_posted_by();
						?>
					</div>
					<?php
					if ( 'post' === get_post_type() ) :
						?>
					<?php endif; ?>
					<?php
					the_content( sprintf(
						wp_kses(
							/* translators: %s: Name of current post. Only visible to screen readers */
							__( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'amp' ),
							array(
								'span' => array(
									'class' => array(),
								),
							)
						),
						get_the_title()
					) );

				//	wp_link_pages( array(
				//		'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'amp' ),
				//		'after'  => '</div>',
				//	) );
					?>
				</main><!-- #main -->
			</div>
			<div id="authorContainer" class="column col-2 col-sm-12 col-lg-6 col-xl-4 mx-auto">
				<div id="author" class="card">
					<div class="card-body text-center">
						<?php
						$authorID = get_the_author_meta('ID');
						$avatar = get_field('avatar', 'user_' . $authorID);
						?>
						<figure class="avatar avatar-xl">
							<img 
							alt="..."
							class="img-responsive"
							src="<?php echo esc_url($avatar['url']); ?>">
						</figure>
						<span class="small text-center d-block">Author</span>
						<span class="large d-block"><?php the_author_meta('display_name');?></span>
					</div>
					<div class="card-footer text-center">
						<a class="btn btn-sm" href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ) ) ;?>">About</a>
						<a class="btn btn-sm btn-primary" href="<?php echo get_template_page_url('contact.php');?>">Contact</a>
					<p class="small mt-0 mb-2">
						<?php the_author_meta('user_description');?>
					</p>
					</div>
				</div>
			</div>
		</div>
		<div class="divider"></div>
		<div class="columns">
			<div class="column col-6 col-sm-12">
				<div class="column col-auto text-center mt-layout">
					Share
				</div>
				<div id="share" class="column col-auto">
					<div id="share">
						<a href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink();?>&quote=<?php the_title(); ?>" title="Share on Facebook" target="_blank">
							<i class="fab fa-facebook-f facebook"></i>
						</a>
						<i class="twitter fab fa-twitter"></i>
						<a href="http://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink();?>&title=<?php the_title();?>" target="_blank" title="Share on LinkedIn">
							<i class="fab fa-linkedin-in linkedin"></i>
						</a>
						<a 
						href="mailto:?subject=<<?php the_title();?>>&body=<<?php the_permalink();?>>"
						target="_blank">
							<i class="email fas fa-envelope"></i>
						</a>
					</div>
				</div>
			</div>
			<div class="column col-6 col-sm-12">
				<div class="text-center mt-layout d-block">
					Categories
				</div>
				<div id="categories" class="my-layout text-center">
					<?php $categories = get_the_category();
						$separator = ' ';
						$output = '';
						if ( ! empty( $categories ) ) {
							foreach( $categories as $category ) {
								$output .= '<a class="chip my-1 text-uppercase small" href="' . esc_url( get_category_link( $category->term_id ) ) . '">' . esc_html( $category->name ) . '</a>' . $separator;
							}
							echo trim( $output, $separator );
						}
					?>
				</div>
			</div>
		</div>
		<div class="divider"></div>
		<div id="comments" class="columns mb-2 mt-2">
			<div class="column col-12">
			<?php
				// If comments are open or we have at least one comment, load up the comment template.
				if ( comments_open() || get_comments_number() ) :
					comments_template();
				endif;
			;?>
			</div>
		</div>

		<!-- .entry-footer -->
	</div>
</article><!-- #post-<?php the_ID(); ?> -->
