<?php
/**
 * Custom Post Type Block Template.
 *
 * @param   array $block The block settings and attributes.
 * @param   string $content The block inner HTML (empty).
 * @param   bool $is_preview True during backend preview render.
 * @param   int $post_id The post ID the block is rendering content against.
 *          This is either the post ID currently being displayed inside a query loop,
 *          or the post ID of the post hosting this block.
 * @param   array $context The context provided to the block by the post or it's parent block.
 */

 // WordPress Classes
 $class_name = 'cta';
 if (!empty($block['class_name'])) {
     $class_name .= ' cta ' . $block['class_name'];
 }
 
 if (!empty($block['align'])) {
     $class_name .= ' align' . $block['align'];
 }
 
 // Support custom "anchor" values.
 $anchor = '';
 if ( ! empty( $block['anchor'] ) ) {
     $anchor = 'id="' . esc_attr( $block['anchor'] ) . '" ';
 }

 // General (NOT WORKING PROPERLY)
$ID = get_field('id');
$class = get_field('class');

// Content
$image_ID = get_field('image');
$image = wp_get_attachment_image_src($image_ID, 'large');
$image_location = get_field('image_location');
$eyebrow = get_field('eyebrow');
$header = get_field('header');
$content = get_field('content');
$buttons = get_field('buttons');

// Style
$color = get_field('color');
$background_image = get_field('background_image');
$background_image_array = get_field('background_image');
$background_position = get_field('background_position');
$background_size = get_field('background_size');
$background_image_ID = $background_image_array['ID'];
$background_image = wp_get_attachment_image_src($background_image_ID, 'large');

//CTA
$cta_type = get_field('cta_type');
$custom = get_field('custom');

;?>

<div id="<?=$ID;?>" class="<?=$class_name;?> <?=$class;?> py-5 position-relative p bg-<?=$color;?>-light" style="background-image: url('<?=$background_image[0];?>'); background-position: <?=$background_position;?>; background-repeat: no-repeat; background-size: <?=$background_size;?>">
    <div class="container">
        <div class="row align-items-center justify-content-center g-">
            <div class="col-10">
                <div class="row align-items-center justify-content-center">
                    <?php if($image):?>
                        <div class="col-12 col-lg-6 pb-3 pb-lg-0 text-center <?=$image_location;?>">
                            <img class="img-fluid" src="<?=$image[0];?>" alt="cta-image">
                        </div>
                        <div class="col-12 col-lg-6 text-center text-lg-start">
                            <?php if($eyebrow):?>
                                <div class="pb-3 small text-<?=$color;?>-dark">
                                    <?=$eyebrow;?>
                                </div>
                            <?php endif;?>
                            <h2 class="text-<?=$color;?>-dark"><?=$header;?></h2>
                            <?php if($content):?>
                                <p><?=$content;?></p>
                            <?php endif;?>
                            <?php if($buttons):?>
                                <?php foreach( $buttons as $post ): 
                                $button = $post['button'];
                                $type = $post['type'];?>
                                    <a class="btn btn-<?=$type;?> d-inline-block mb-3" href="<?=$button['url'];?>" target="<?=$button['target'];?>"><?=$button['title'];?></a>
                                <?php endforeach;?>
                            <?php endif;?>
                        </div>
                    <?php else:?>
                        <div class="col-12 col-lg-6 text-center text-lg-start">
                            <?php if($eyebrow):?>
                                <div class="pb-3 small text-<?=$color;?>-dark">
                                    <?=$eyebrow;?>
                                </div>
                            <?php endif;?>
                            <h2 class="text-<?=$color;?>-dark"><?=$header;?></h2>
                        </div>
                        <div class="col-12 col-lg-6 text-center text-lg-start">
                            <?php if($content):?>
                                <p><?=$content;?></p>
                            <?php endif;?>
                            <?php if($buttons):?>
                                <?php foreach( $buttons as $post ): 
                                $button = $post['button'];
                                $type = $post['type'];?>
                                    <a class="btn btn-<?=$type;?> d-inline-block mb-3" href="<?=$button['url'];?>"><?=$button['title'];?></a>
                                <?php endforeach;?>
                            <?php endif;?>
                        </div>
                    <?php endif;?>
                </div>
            </div>
        </div>
        <?=$custom;?>
    </div>
</div>
