<?php
/**
 * Hero Block Template.
 *
 * @param   array $block The block settings and attributes.
 * @param   string $content The block inner HTML (empty).
 * @param   bool $is_preview True during backend preview render.
 * @param   int $post_id The post ID the block is rendering content against.
 *          This is either the post ID currently being displayed inside a query loop,
 *          or the post ID of the post hosting this block.
 * @param   array $context The context provided to the block by the post or it's parent block.
 */

 // WordPress Classes
$class_name = 'hero';
if (!empty($block['class_name'])) {
    $class_name .= ' ' . $block['class_name'];
}

if (!empty($block['align'])) {
    $class_name .= ' align' . $block['align'];
}

// Support custom "anchor" values.
$anchor = '';
if ( ! empty( $block['anchor'] ) ) {
    $anchor = 'id="' . esc_attr( $block['anchor'] ) . '" ';
}

// Content
$image_ID = get_field('image');
$image = wp_get_attachment_image_src($image_ID, 'large');
$image_location = get_field('image_location');
$eyebrow = get_field('eyebrow');
$header = get_field('header');
$content = get_field('content');
$buttons = get_field('buttons');
$breadcrumbs = get_field('breadcrumbs');

// Style


// Widgets
$widget_1 = get_field('widget_1');
    if($widget_1){
        $widget_1_header = get_field('widget_1_header');
        $widget_1_testimonials = get_field('widget_1_testimonials');
    };

// Style
$color = get_field('color');
$background_image = get_field('background_image');
$background_image_array = get_field('background_image');
$background_position = get_field('background_position');
$background_size = get_field('background_size');
$background_image_ID = $background_image_array['ID'];
$background_image = wp_get_attachment_image_src($background_image_ID, 'large');

//CTA
$cta_type = get_field('cta_type');
$custom = get_field('custom');

?>
<div class="hero position-relative bg-<?=$color;?>-light" style="background-image: url('<?=$background_image[0];?>'); background-position: <?=$background_position;?>; background-repeat: no-repeat; background-size: <?=$background_size;?>">
    <div class="container col-12">
        <div class="row <?php if($image):?>align-items-center py-5<?php endif;?> justify-content-center">
            <?php if($image):?>
                <div class="hero-image col-md-12 col-lg-6 p-0 order-lg-1 mb-n4">
                    <img class="img-fluid" src="<?=$image[0];?>" alt="<?=the_title();?>-hero">
                </div>
            <?php endif;?>
            <div class="hero-content col-lg-6 text-center <?php if($image):?>text-lg-start <?php endif;?>my-5 mx-auto">
                <?if(!is_front_page() and $breadcrumbs):?>
                    <?php
                    $ID = get_the_ID();
                    $parent_ID = wp_get_post_parent_id($ID);
                    $post_type_slug = get_post_type();
                    $homepage_ID = get_option('page_on_front');
                    if($post_type_slug == 'page'):?>
                        <div class="breadcrumb align-items-center m-0 pb-5 d-inline-flex <?php if(!$image):?>d-inline-flex<?php endif;?>">
                            <a class="breadcrumb-item fw-normal" href="<?= home_url(); ?>"><span class="icon-home"></span></a>
                            <a class="breadcrumb-item text-dark fw-bold"> <span class="breadcrumb-item"><?= get_the_title(); ?></a>
                        </div>
                        
                    <?php elseif($parent_ID == 0):?>
                        <?php
                        $post_type_slug = get_post_type();
                        $post_type_name = ucfirst($post_type_slug);
                        $post_type_link = get_post_type_archive_link($post_type_slug);
                        ?>
                        <div class="breadcrumb align-items-center m-0 pb-5 d-inline-flex <?php if(!$image):?>d-inline-flex<?php endif;?>">
                            <a class="breadcrumb-item fw-normal text-light" href="<?= $post_type_link; ?>"><?= $post_type_name; ?></a>
                            <a class="breadcrumb-item text-dark fw-bold"> <span class="breadcrumb-item"><?= get_the_title(); ?></a>
                        </div>

                    <?php endif;?>
                <?php endif;?>
                <?php if($eyebrow):?>
                    <div class="pb-3 small text-<?=$color;?>-dark">
                        <?=$eyebrow;?>
                    </div>
                <?php endif;?>
                <?php if($header):?>
                    <h1 class="display-4 fw-bold lh-1 mb-3"><?=$header;?></h1>
                <?php endif;?>
                <?php if($content):?>
                    <p class="col-lg-10 fs-5 text-light <?php if(!$image):?>mx-auto<?php endif;?>"><?=$content;?></p>
                <?php endif;?>
                <?php if($buttons):?>
                    <div class="row g-3">
                        <div class="col-12 text-center <?php if($image):?>text-lg-start<?php endif;?>">
                            <?php if($buttons):?>
                                <?php foreach( $buttons as $post ): 
                                $button = $post['button'];
                                $type = $post['type'];?>
                                    <a class="btn btn-lg btn-<?=$type;?> d-inline-block mb-3" href="<?=$button['url'];?>" target="<?=$button['target'];?>"><?=$button['title'];?></a>
                                <?php endforeach;?>
                            <?php endif;?>
                        </div>
                    </div>
                <?php endif;?>
                <?php if($widget_1):?>
                    <div id="hero-widget-1" class="row align-items-center mt-5 pt-3">
                        <div class="col-6 border-top pb-5 mx-auto mx-lg-0">
                        </div>
                        <div id="widget-1-half-border" class="col-12">
                            <h3 class="fs-5"><?=$widget_1_header;?></h3>
                        </div>
                        <div class="col-12">
                            <div class="row">
                                <?php 
                                foreach( $widget_1_testimonials as $post ): 
                                setup_postdata($post);
                                $widget_1_image = get_the_post_thumbnail_url($post->ID);
                                $widget_1_testimonials = get_field('rating');
                                ?>
                                <div class="col-4">
                                    <?php include get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/inc/testimonial-rating.php';?>
                                </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                <?php endif;?>
                <?php wp_reset_postdata(); ?>
            </div>
        </div>
    </div>
</div>