<?php
/**
 * Hero Block Template.
 *
 * @param   array $block The block settings and attributes.
 * @param   string $content The block inner HTML (empty).
 * @param   bool $is_preview True during backend preview render.
 * @param   int $post_id The post ID the block is rendering content against.
 *          This is either the post ID currently being displayed inside a query loop,
 *          or the post ID of the post hosting this block.
 * @param   array $context The context provided to the block by the post or it's parent block.
 */

 // WordPress Classes
 $class_name = 'hero';
 if (!empty($block['class_name'])) {
     $class_name .= ' ' . $block['class_name'];
 }
 
 if (!empty($block['align'])) {
     $class_name .= ' align' . $block['align'];
 }
 
 // Support custom "anchor" values.
 $anchor = '';
 if ( ! empty( $block['anchor'] ) ) {
     $anchor = 'id="' . esc_attr( $block['anchor'] ) . '" ';
 }

// Content
$eyebrow = get_field('eyebrow');
$header = get_field('header');
$content = get_field('content');

// Services
$services = get_field('services');

// Style
$color = get_field('color');
$background_image = get_field('background_image');
$background_image_array = get_field('background_image');
$background_image_ID = $background_image_array['ID'];
$background_image = wp_get_attachment_image_src($background_image_ID, 'large');

// CTA
$cta_type = get_field('cta_type');
$custom = get_field('custom');

// Developer
$id = get_field('id');
$class = get_field('class');
?>

<div id="<?=$id;?>" class="<?=$class;?> services py-5 position-relative p bg-<?=$color;?>-hover" style="background-image: url('<?=$background_image[0];?>'); background-position: bottom right; background-repeat: no-repeat;">
    <div class="container">
        <div class="row">
            <div class="col-12 col-md-10 col-lg-6 mx-auto text-center">
                <div class="pb-3 small text-<?=$color;?>-contrast">
                    <?=$eyebrow;?>
                </div>
                <h2 class="text-<?=$color;?>-contrast"><?=$header;?></h2>
            </div>
        </div>
        <div class="row g-5 py-5 justify-content-center">
            <?php
            foreach( $services as $post ): 
            setup_postdata($post);
            ?>
            <div class="col-12 col-md-6 col-lg-5">
                <?php include get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/inc/services-excerpt.php';?>
            </div>
            <?php endforeach;
            wp_reset_postdata();?>
        </div>
        <?=$custom;?>
    </div>
</div>
