<?php
/**
 * Testimonial Block Template.
 *
 * @param   array $block The block settings and attributes.
 * @param   string $content The block inner HTML (empty).
 * @param   bool $is_preview True during backend preview render.
 * @param   int $post_id The post ID the block is rendering content against.
 *          This is either the post ID currently being displayed inside a query loop,
 *          or the post ID of the post hosting this block.
 * @param   array $context The context provided to the block by the post or it's parent block.
 */

 // WordPress Classes
$class_name = 'hero';
if (!empty($block['class_name'])) {
    $class_name .= ' ' . $block['class_name'];
}

if (!empty($block['align'])) {
    $class_name .= ' align' . $block['align'];
}

// Support custom "anchor" values.
$anchor = '';
if ( ! empty( $block['anchor'] ) ) {
    $anchor = 'id="' . esc_attr( $block['anchor'] ) . '" ';
}

// Content
$eyebrow = get_field('eyebrow');
$header = get_field('header');
$content = get_field('content');
$testimonials = get_field('testimonials');

// Style
$color = get_field('color');
$background_image_array = get_field('background_image');
$background_image_ID = $background_image_array['ID'];
$background_image = wp_get_attachment_image_src($background_image_ID, 'medium');
$background_position = get_field('background_position');
$background_size = get_field('background_size');
$color = get_field('color');
$rounded = get_field('rounded');

//Math
$testimonials_count = count($testimonials);
?>
<?php if($testimonials_count <= 1):?>
<style>
    section.testimonial-section .quote-open {
        font-size: 200px !important;
        line-height: 200px;
        position: absolute;
        left: 0px;
        top: 0px;
        z-index: 0;
    }
    section.testimonial-section .quote-closed {
        font-size: 200px !important;
        line-height: 200px;
        position: absolute;
        bottom: 0px;
        right: 50px;
        z-index: 0;
    }
</style>
<div class="testimonials py-5 position-relative p bg-<?=$color;?>-light-hover">
    <section class="testimonial-section">
        <div class="container">
            <div class="row">
                <?php if($eyebrow or $header or $body):?>
                    <div class="col-12 col-md-10 col-lg-6 mx-auto text-center">
                        <?php if($eyebrow):?>
                            <div class="pb-3 small text-<?=$color;?>-contrast">
                                <?=$eyebrow;?>
                            </div>
                        <?php endif;?>
                        <?php if($header):?>
                            <h2 class="text-<?=$color;?>-contrast"><?=$header;?></h2>
                        <?php endif;?>
                        <?php if($content):?>
                            <?=$content;?>
                        <?php endif;?>
                    </div>
                <?php endif;?>
                <div class="col-12">
                    <?php
                    foreach( $testimonials as $post ): 
                    setup_postdata($post);
                    $name = $post->name;
                    $company_name = $post->company_name;
                    $position = $post->position;
                    $quote = $post->quote;
                    $image_ID = $post->featured_image;
                    $image = wp_get_attachment_image_src($image_ID, 'medium');
                    
                    // Variable font size for content
                    $content_count = strlen($quote);
                    if($content_count <= 50){
                        $fs = "fs-1";
                    } elseif($content_count <= 150){
                        $fs = "fs-2";
                    } elseif($content_count <= 300){
                        $fs = "fs-4";
                    } else{
                        $fs = "fs-5";
                    };
                    ?>
                        <div class="card bg-<?=$color;?>-dark-hover" style="background-image: url('<?=$background_image[0];?>'); background-position: <?=$background_position;?>; background-repeat: no-repeat; background-size: <?=$background_size;?>">
                            <div class="card-body">
                                <div class="row d-flex align-items-center">
                                    <div class="col-lg-5 testimonial-img">
                                        <img class="img-fluid d-flex mx-auto <?=$rounded;?>" style="width: 50%; max-width: 300px;" height="auto" width="auto" alt="#"
                                            src="<?= $image[0]; ?>"></img>
                                    </div>
                                    <div class="col-lg-7 py-5 position-relative">
                                        <span class="quote-open d-none d-lg-flex text-<?=$color;?>-hover">"</span>
                                        <div class="<?=$fs;?> text-<?=$color;?>-contrast pb-5 position-relative" style="z-index:1"><?=$quote;?></div>
                                        <span class="quote-closed d-none d-lg-flex text-<?=$color;?>">"</span>
                                        <span class="testimonial-name d-block text-<?=$color;?>-light-hover fw-bold fs-5"><?=$name;?></span>
                                        <?php if($position):?>
                                        <span class="testimonial-desg text-<?=$color;?>"><?=$position;?></span>
                                        <?php endif;?>
                                        <?php if($company_name):?>
                                        <span class="testimonial-desg text-<?=$color;?>-contrast"><?=$company_name;?></span>
                                        <?php endif;?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php 
                    endforeach;?>
                </div>
            </div>
        </div>
    </section>
</div>
<?php elseif($testimonials_count >= 2):?>
<style>
    section.testimonial-section .quote-open {
        font-size: 200px !important;
        line-height: 200px;
        position: absolute;
        left: 0px;
        top: 0px;
        z-index: 0;
    }
    section.testimonial-section .quote-closed {
        font-size: 200px !important;
        line-height: 200px;
        position: absolute;
        bottom: 0px;
        right: 50px;
        z-index: 0;
    }
</style>
<div class="testimonials py-5 position-relative p bg-<?=$color;?>">
    <section class="testimonial-section d-flex align-items-center">
        <div class="container">
            <div class="row">
                <?php if($eyebrow or $header or $content):?>
                    <div class="col-12 col-md-10 col-lg-6 mx-auto text-center">
                        <?php if($eyebrow):?>
                            <div class="pb-3 small text-<?=$color;?>-contrast">
                                <?=$eyebrow;?>
                            </div>
                        <?php endif;?>
                        <?php if($header):?>
                            <h2 class="text-<?=$color;?>-contrast"><?=$header;?></h2>
                        <?php endif;?>
                        <?php if($content):?>
                            <?=$content;?>
                        <?php endif;?>
                    </div>
                <?php endif;?>
            </div>
            <div class="row align-items-center g-0">
                <div class="col-auto">
                    <button class="btn btn-sm text-<?=$color;?>-contrast p-1" type="button" data-bs-target="#testimonials_carousel" data-bs-slide="prev">
                        <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                        <span class="visually-hidden">Previous</span>
                    </button>
                </div>
                <div class="col">
                    <div id="testimonials_carousel" class="carousel slide carousel-fade">
                        <div class="carousel-inner">
                            <?php
                            $count = 0;
                            foreach( $testimonials as $post ): 
                            setup_postdata($post);
                            $name = $post->name;
                            $company_name = $post->company_name;
                            $position = $post->position;
                            $quote = $post->quote;
                            $image_ID = $post->featured_image;
                            $image = wp_get_attachment_image_src($image_ID, 'medium');
                            ?>
                            <div class="carousel-item <?php if($count==0):?>active<?php endif;?>">
                                <div class="card bg-<?=$color;?>-hover" style="min-height: 400px; background-image: url('<?=$background_image[0];?>'); background-position: top left; background-repeat: no-repeat;">
                                    <div class="card-body"> 
                                        <div class="row d-flex align-items-center">
                                            <div class="col-lg-5 testimonial-img">
                                                <img class="img-fluid d-flex mx-auto <?=$rounded;?>" style="width: 50%; max-width: 300px;" height="auto" width="auto" alt="#"
                                                    src="<?= $image[0]; ?>"></img>
                                            </div>
                                            <div class="col-lg-7 py-5 position-relative">
                                                <span class="quote-open d-none d-lg-flex text-<?=$color;?>">"</span>
                                                <div class="fs-4 text-<?=$color;?>-contrast pb-5 position-relative" style="z-index:1"><?=$quote;?></div>
                                                <span class="quote-closed d-none d-lg-flex text-<?=$color;?>">"</span>
                                                <span class="testimonial-name d-block text-<?=$color;?>-light-hover fw-bold fs-5"><?=$name;?></span>
                                                <?php if($position):?>
                                                <span class="testimonial-desg text-<?=$color;?>-contrast"><?=$position;?></span>
                                                <?php endif;?>
                                                <?php if($company_name):?>
                                                <span class="testimonial-desg text-<?=$color;?>-contrast"><?=$company_name;?></span>
                                                <?php endif;?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php 
                            $count++;
                            endforeach;?>
                        </div>
                    </div>
                </div>
                <div class="col-auto">
                    <button class="btn btn-sm text-<?=$color;?>-contrast p-1" type="button" data-bs-target="#testimonials_carousel" data-bs-slide="next">
                        <span class="carousel-control-next-icon" aria-hidden="true"></span>
                        <span class="visually-hidden">Next</span>
                    </button>
                </div>
            </div>
        </div>
    </section>
</div>
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.3.1/js/bootstrap.bundle.min.js"></script>
<?php endif;?>