<?php
/**
 * Template Name: Privacy Policy
 * The template for displaying the privacy policy 
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

get_header();

$privacyPolicy = get_template_page_url('privacy-policy.php');
$terms = get_template_page_url('terms.php');
$cookie = get_template_page_url('cookie-policy.php');
$sitemap = get_template_page_url('sitemap.php');
$press = get_template_page_url('press.php');
$brand = get_template_page_url('brand.php');
$clientName = get_field('client_name', 'option');
$siteURL = get_site_url();
?>

<style>
	#resourcesMenu a {
		color: #999999;
	}
	#resourcesMenu a:hover, #resourcesMenu .current {
		color: #000000;
		background: <?php the_field('color_gray', 'option');?>25;
	}
	#resourcesMenu i{
		height: 20px;
    	width: 40px;
    	text-align: center;
	}
</style>
<script>
function printScreen() {
    window.print();
}
</script>
<main>
	<div class="container">
		<div class="row">
			<div class="col my-4">
				<?php if(!is_front_page()): ?>
				<?php get_breadcrumb(); ?>
				<?php endif; ?>
			</div>
		</div>
	</div>
	<div class="container">
		<div class="row">
			<div class="col-12 col-lg-9 order-lg-2">
				<article id="privacy-policy" class="mb-5">
					<div class="row">
						<div class="col">
						<h1>Privacy Policy</h1>
						<p class="text-muted">Updated <?php echo the_modified_date();?></p>
						</div>
						<div class="col-auto">
						<button class="btn btn-lg btn-primary hidden-print" onclick="printScreen()"><span aria-hidden="true"></span> Print</button>
						</div>
					</div>
					<hr>
					<p>This page explains the privacy practices for the website for <?php echo $clientName ;?>. We always work diligently to prevent the unauthorized sale or use of your personal information, and work to prevent the accidental loss of such information as well. For this reason, <?php echo $clientName ;?> does not share, distribute or sell any personally identifiable information with third parties, unless the law requires us to do so.</p>

					<h3>Personal Information Collection</h3>
					<p>We may record your location, IP address, the URLs of the website that directed you to our site, the URLs of the pages you visit on our website, the dates and times of each visit, and/or information about the computer hardware and software you use, as well as other information that may be available. <?php echo $clientName ;?> uses this information only for the operation and maintenance of our website and also to provide general statistics regarding the use of our services. We may also use this website to collect certain personally identifiable information. This may sometimes include your name, contact information and/or other data. We may also collect additional personal or non-personal information about you in the future or collect certain information about other visitors.</p>

					<h3>Details About the Use of Collected Information</h3>
					<p><?php echo $clientName ;?> may collect and use your personal information as part of the operation of our website. We also use this information to deliver the information or service you request, and also to improve your browsing experience and the experience of other visitors by personalizing the site. We may use information about the content you visit and services you use alone or in conjunction with information collected from other users. This helps us tailor our services to better suit the needs and interests of our users.</p>

					<p>At <?php echo $clientName ;?>, we do not sell, rent or lease any of our customer lists or information to third parties. Therefore, we reserve the right to disclose any information that we obtain through our website to appropriate authorities, without notice, if required by law or any governmental agency.</p>

					<h3>Security Disclaimer for Our Website</h3>
					<p>Information sent through contact forms and emails to <?php echo $clientName ;?> may not be secure. Since this is the case, you choose to share this information at your own risk.</p>
				</article>
			</div>
			<div class="col-12 col-lg-3 order-lg-1">
				<div id="resourcesMenu" class="sticky-top mb-5 card">
					<div class="accordion small">
						<div class="accordion-item">
							<li class="border-0 accordion-button" data-toggle="collapse"
								data-target="#toggle-legal">
								<h2 class="small text-uppercase my-2"><strong>Legal</strong></h2>
							</li>
							<div id="toggle-legal" class="collapse show" data-parent="#accordion">
								<?php if($privacyPolicy){echo '<a class="privacy d-block list-group-item list-group-item-action border-0 current" href="' . $privacyPolicy . '"><i class="fas fa-file-alt px-2"></i> Privacy Policy</a>';};?>
								<?php if($cookie){
								echo '<a class="cookie d-block list-group-item list-group-item-action border-0" href="' . $cookie . '"><i class="fas fa-cookie-bite px-2"></i> Cookie Policy</a>'; };?>
								<?php if($terms){echo '<a class="terms d-block list-group-item list-group-item-action border-0" href="' . $terms . '"><i class="fas fa-gavel px-2"></i> Terms of Service</a>';};?>
							</div>
						</div>
						<hr class="m-0">
						<div class="accordion-item">
							<li class="collapsed border-0 accordion-button" data-toggle="collapse"
								data-target="#toggle-resources">
								<h2 class="small text-uppercase my-2"><strong>Resources</strong></h2>
							</li>
							<div id="toggle-resources" class="collapse" data-parent="#accordion">
								<?php if($sitemap){echo '<a class="sitemap d-block list-group-item list-group-item-action border-0" href="' . $sitemap . '"><i class="fas fa-sitemap px-2"></i> Sitemap</a>';};?>
								<?php if($press){echo '<a class="terms d-block list-group-item list-group-item-action border-0" href="' . $press . '"><i class="fas fa-copyright px-2"></i></i>Press</a>';};?>
								<?php if($brand){echo '<a class="terms d-block list-group-item list-group-item-action border-0" href="' . $brand . '"><i class="fas fa-palette px-2"></i></i>Brand</a>';};?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</main>
