<?php
/**
 * Template Name: Single Resources
 * The template for displaying the Single Resources.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

get_header();

// Options - Theme Settings
$default_featured_image = get_field('resources_default_featured_image', 'option');

// Post - WP
$title = get_the_title();
if (has_post_thumbnail($post->ID)) {
    $featured_image = get_the_post_thumbnail(get_the_ID(), 'header-banner', array('class' => 'rounded img-fluid'));
} else{
    
};

// Post - ACF
$builder = get_field('builder');
$featured_content_format = get_field('featured_content_format');
$featured_video_youtube_ID = get_field('featured_video_youtube_ID');
$h1 = get_field('h1');
$h2 = get_field('h2');
$wp_content = get_the_content();
$acf_content = get_field('content');
$category = get_the_category();
$category_url = esc_url(get_category_link($category[0]->term_id));
$lead = get_field('lead');
$authorID = get_the_author_meta('ID');
$avatar = get_field('avatar', 'user_' . $authorID);
$size = "thumbnail";
$pageLink = get_field('pageLinkTeam', 'user_' . $authorID);
$author_name = get_author_name();
$color = 'primary';

// Builder
if($builder == 'wordpress'){
    $content = $wp_content;
} else {
    $content = $acf_content;
};

// Featured Image
if (has_post_thumbnail($post->ID)) {
    $featured_image = get_the_post_thumbnail(get_the_ID(), 'header-banner', array('class' => 'rounded img-fluid'));
} else{
    $featured_image = get_field('featured_image');
};

// CTA
$primary_cta_source = get_field('primary_cta_source');
?>
<style>
    img.alignright {
        float: right;
        padding: 10px;
    }
    img.alignleft {
        float: left;
        padding: 10px;
    }
</style>
<main>
    <div class="container py-3">
        <div class="row">
            <div class="col-12">
                <?php 
                $post_type_slug = get_post_type();
                $post_type_name = ucfirst($post_type_slug);
                $post_type_link = get_post_type_archive_link($post_type_slug);
                $types = get_the_terms( $post->ID, 'resource_type' );
                ;?>
                <div class="breadcrumb align-items-center m-0 small text-muted justify-content-center text-lg-start justify-content-lg-start">
                    <a class="breadcrumb-item fw-bold" href="<?= $post_type_link; ?>"><?= $post_type_name; ?></a>
                    <span class="breadcrumb-item fw-bold">                        <?php 
                        foreach ( $types as $type ) {
                            echo $type->name; // or whatever value
                        };?></span>
                </div>
            </div>
        </div>
    </div>
    <div class="hero position-relative border" style="background-image: url('<?=$background_image[0];?>'); background-position: <?=$background_position;?>; background-repeat: no-repeat; background-size: <?=$background_size;?>">
        <div class="container">
            <div class="row <?php if($featured_image):?>align-items-center justify-content-lg-start <?php endif;?> justify-content-center">
                <div class="col-12 text-center <?php if($featured_image):?>col-lg-8 text-lg-start <?php endif;?> mx-auto">
                    <div class="pb-3 pt-5 text-uppercase text-<?=$color;?>-dark">
                        <?php 
                        foreach ( $types as $type ) {
                            echo $type->name; // or whatever value
                        };?>
                    </div>
                    <?php if($header):?>
                        <h1 class="display-4 fw-bold lh-1 mb-3"><?=$header;?></h1>
                    <?php else:?>
                        <h1 class="display-4 fw-bold lh-1 mb-3"><?=the_title()?></h1>
                    <?php endif;?>
                </div>
                <?php if($featured_image):?>
                    <div id="hero-image" class="col-12 col-sm-8 col-lg-4 d-block p-0 mx-auto">
                        <?= $featured_image;?>
                    </div>
                <?php endif;?>
            </div>
        </div>
    </div>
    <div class="container py-5">
        <div class="row justify-content-center">
            <?php if($primary_cta_source):?>
                <div class="col-10 col-md-8 col-lg-4 order-lg-2">
                    <div id="sidebar" class="sticky-top">
                        <?php if ($primary_cta_source == 'custom'):?>
                            <?php the_field('primary_cta_custom');?> 
                        <?php else:?>
                            <?php if ($primary_cta_source == 'template'):?>
                                <?php get_template_part('/template-parts/' . get_field('template', 'option') . '/inc/cta/global-cta-sm');?>
                            <?php else:?>
                                <?php $args = array(
                                    'cta_prefix' => $sidebar_cta_source,
                                    'sourceID'   => 'option'
                                );?>
                            <?php endif;?>
                        
                        <?php endif;?>

                        <?php
                        // Newsletter CTA
                        // first check if there's a Newsletter CTA
                        if ($newsletter_cta_source) { ?>
                            <?php
                            if ($newsletter_cta_source == 'custom') {
                                the_field('newsletter_cta_html', $blog_ID);
                            } else {
                                include get_template_directory() . '/template-parts/' . get_field('template', 'option') . '/inc/cta/newsletter.php';
                            }
                            ?>
                        <?php } ?>
                        <script>
                        var h = document.getElementById('header').clientHeight;
                        document.getElementById("sidebar-ctas").style.top = h + 15 + 'px';
                    </script>
                    </div>
                <?php endif;?>
                <div class="col-12 col-lg-8 order-lg-1">
                    <article id="article">
                        <?php if($content):?>
                            <p class="col-lg-10 fs-5 text-light <?php if(!$featured_image):?>mx-auto<?php endif;?>"><?=$content;?></p>
                        <?php endif;?>
                    </article>
                </div>
            </div>
        </div>
    </div>
</main>
<?php

get_footer();
