<?php
/**
 * Template Name: Sitemap
 * The template for displaying the sitemap
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

get_header();
$privacyPolicy = get_template_page_url('privacy-policy.php');
$terms = get_template_page_url('terms.php');
$cookie = get_template_page_url('cookie-policy.php');
$sitemap = get_template_page_url('sitemap.php');
$press = get_template_page_url('press.php');
$brand = get_template_page_url('brand.php');
$excludePages = get_field('pages_to_exclude');
if($excludePages){
	$exclude = implode(",", $excludePages);
} else {
    $exclude = 0;
};

?>
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.4/jquery.min.js"></script>
<link
  rel="stylesheet"
  href="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.css"
/>
<!-- add after bootstrap.min.js or bootstrap.bundle.min.js -->
<script src="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.js"></script>
<style>
	#resourcesMenu a {
		color: #999999;
	}

	#resourcesMenu a:hover,
	#resourcesMenu .current {
		color: #000000;
		background: <?php the_field('color_gray', 'option');
		?>25;
	}

	#resourcesMenu i {
		height: 20px;
		width: 40px;
		text-align: center;
	}

    /* Sitemap */
    #sitemap ol, #sitemap ul {
        margin-left: 1.5rem;
        padding:0px;
    }
    #sitemap .list-group{
        height: 10rem;
        overflow: hidden;
    }
    #sitemap .card-sitemap.show .list-group {
        height: auto;
        overflow: auto;
    }
    #sitemap .card-sitemap.show .sitemap-show {
        display:none;
    }
    #sitemap a.list-group-item:hover {
        background: var(--gray-color-light);
    }
    .list-group-item-title {
        color: var(--gray-color-dark);
        border-left: 0px !important;

    }
    .list-group-item-title:hover {
        background: none !important;
        color: var(--gray-color-dark);
    }
    
    /* TOC */
    nav[data-toggle=toc] .nav-link.active, nav[data-toggle=toc] .nav-link.active:focus, nav[data-toggle=toc] .nav-link.active:hover {
        color: black !important;
        font-weight: bold !important;
        border-left: 2px solid #000 !important;
        background: var(--bs-light)
    }
    nav[data-toggle=toc] .nav>li>a:focus, nav[data-toggle=toc] .nav>li>a:hover {
        color: #000 !important;
    }
</style>
<main>
	<div class="container">
		<div class="row">
			<div class="col my-4">
				<?php if(!is_front_page()): ?>
				<?php get_breadcrumb(); ?>
				<?php endif; ?>
			</div>
		</div>
	</div>
	<div class="container mb-4">
		<div class="row g-4">
            <div id="table-of-contents" class="col-12 col-md-2 col-lg-3 col-xl-3 d-none d-lg-block">
                <div id="table-of-contents-card" class="card sticky-top overflow-hidden" style="top:10%">
                    <div class="card-header small text-uppercase text-muted">
                        Contents
                        <script>var h = document.getElementById('header').clientHeight;
                        document.getElementById("table-of-contents-card").style.top = h + 15 + 'px';</script>
                    </div>
                    <div class="my-2">
                        <nav id="toc" data-toggle="toc"></nav>
                    </div>
                </div>
            </div>
			<article id="sitemap" class="col-12 col-lg-9 toc" data-bs-spy="scroll" data-bs-target="#toc" data-bs-offset="0" tabindex="0">
				<h1 class="my-5">Sitemap</h1>
                <hr>
				<div class="row g-4">
					<div id="post-type-pages" class="col-12 card-sitemap">
                        <h3 class="list-group-item border-0 fw-bold list-group-item-title fs-6" disabled>Pages</h3>
                        <ul class="list-group ms-0 position-relative">
                            <?php
                            wp_reset_postdata(); ?>
                            <?php $args = array(
                                'authors' => '',
                                'child_of' => 0,
                                'date_format' => get_option( 'date_format' ),
                                'depth' => 0,
                                'echo' => 1,
                                'exclude' => $exclude + $post->ID,
                                'include' => '',
                                'link_after' => '',
                                'link_before' => '',
                                'post_type' => 'page',
                                'post_status' => 'publish',
                                'show_date' => '',
                                'sort_column' => 'menu_order, post_title',
                                'sort_order' => '',
                                'title_li' => __( '' ),
                                'walker' => new Wdm_Walker_Page()
                            );

                            echo wp_list_pages( $args ) ;?>
                        </ul>
                            <a class="list-group-item btn-sm text-center card-sitemap sitemap-show" data-toggle="collapse" data-target="#post-type-pages" href="">View All</a>
					</div>
                    <hr>
                    <?php 
                    foreach( get_post_types( array('public' => true, 'has_archive' => true, '_builtin' => false) ) as $post_type ):?>
                        <?php if($post_type !== 'contact'):?>
                        <?php
                        $cpt = get_post_type_object( $post_type )
                        ;?>
                        <div id="post-type-<?php echo $post_type;?>" class="col-12 mb-4 card-sitemap">
                            <a class="list-group-item border-0 list-group-item-title" href="<?php echo get_post_type_archive_link( $post_type );?>"><h3 class="fs-6 fw-bold"><?php echo $cpt->labels->name;?></h3></a>
                                <?php
                                wp_reset_postdata(); ?>
                                <?php $args = array(
                                    'authors' => '',
                                    'child_of' => 0,
                                    'date_format' => get_option( 'date_format' ),
                                    'depth' => 0,
                                    'echo' => 1,
                                    'exclude' => $exclude,
                                    'include' => '',
                                    'link_after' => '',
                                    'link_before' => '',
                                    'post_type' => $post_type,
                                    'post_status' => 'publish',
                                    'show_date' => '',
                                    'sort_column' => 'menu_order, post_title',
                                    'sort_order' => '',
                                    'title_li' => __( '' ),
                                    'walker' => new Wdm_Walker_Page()
                                );
                                $number = count(get_pages($args));
                                if($number < 4):?>
                                    <ul class="list-group ms-0 position-relative">
                                        <?php echo wp_list_pages( $args );?>
                                    </ul>
                                <?php else:?>
                                    <ul class="list-group ms-0 position-relative">
                                        <?php echo wp_list_pages( $args );?>
                                    </ul>
                                    <div class="list-group-item btn btn-sm btn-outline-primary mx-4 card-sitemap sitemap-show" data-toggle="collapse" data-target="#post-type-<?php echo $post_type;?>" href="">View All</div>
                                <?php endif;?>
                        </div>
                        <hr>
                        <?php endif;?>
                    <?php endforeach;?>
                    <div id="post-type-posts" class="col-12 card-sitemap">
                        <?php
                            global $post;

                            $posts = get_posts( array(
                                'numberposts'		=> -1,
                                'post_type'			=> 'post',
                                'orderby'			=> 'date',
                                'order'				=> 'DESC',
                            ) );
                            $n = count($posts);
                        ?>
                        <h3 class="list-group-item border-0 fw-bold list-group-item-title fs-6" disabled>Posts</h3>
                        <ul class="list-group ms-0 position-relative">

                            <?php foreach ( $posts as $post ) : 
                            setup_postdata( $post );?>
                                <div class="col-12 mx-auto">
                                    <a class="list-group-item border-0 text-truncate" title="<?php the_title();?>" href="<?php the_permalink();?>"><?php the_title();?></a>
                                </div>
                            <?php endforeach;
                                wp_reset_postdata();?>
                        </ul>
                        <a class="list-group-item btn-sm text-center card-sitemap sitemap-show" data-toggle="collapse" data-target="#post-type-posts" href="">View All</a>
                    </div>
				</div>
            </article>
		</div>
	</div>
</main>
<?php

get_footer();