<?php
/**
 * Hero Block Template.
 *
 * @param   array $block The block settings and attributes.
 * @param   string $content The block inner HTML (empty).
 * @param   bool $is_preview True during backend preview render.
 * @param   int $post_id The post ID the block is rendering content against.
 *          This is either the post ID currently being displayed inside a query loop,
 *          or the post ID of the post hosting this block.
 * @param   array $context The context provided to the block by the post or it's parent block.
 */

 // WordPress Classes
 $class_name = 'hero';
 if (!empty($block['class_name'])) {
     $class_name .= ' ' . $block['class_name'];
 }
 
 if (!empty($block['align'])) {
     $class_name .= ' align' . $block['align'];
 }
 
 // Support custom "anchor" values.
 $anchor = '';
 if ( ! empty( $block['anchor'] ) ) {
     $anchor = 'id="' . esc_attr( $block['anchor'] ) . '" ';
 }

// Content
$eyebrow = get_field('eyebrow');
$header = get_field('header');
$content = get_field('content');

// Custom Post Type
$cpt = get_field('cpt');

// Style
$design = get_field('design');
$color = get_field('color');
$background_image = get_field('background_image');
if($background_image){
$background_image_array = get_field('background_image');
$background_position = get_field('background_position');
$background_size = get_field('background_size');
$background_image_ID = $background_image_array['ID'];
$background_image = wp_get_attachment_image_src($background_image_ID, 'large');

$size_xs = get_field('size_xs');
$size_sm = get_field('size_sm');
$size_md = get_field('size_md');
$size_lg = get_field('size_lg');
$size_xl = get_field('size_xl');
}

//CTA
$cta_type = get_field('cta_type');
$custom = get_field('custom');

// Developer
$id = get_field('id');
$class = get_field('class');
;?>
<div id="<?=$id;?>" class="<?=$class;?> scpt py-5 position-relative p bg-<?=$color;?>-light" style="background-image: url('<?=$background_image[0];?>'); background-position: <?=$background_position;?>; background-repeat: no-repeat; background-size: <?=$background_size;?>">
    <div class="container">
        <div class="row">
            <div class="col-12 col-md-10 col-lg-6 mx-auto text-center">
                <?php if($eyebrow):?>
                    <div class="pb-3 small text-<?=$color;?>-contrast">
                        <?=$eyebrow;?>
                    </div>
                <?php endif;?>
                <h2 class="text-body"><?=$header;?></h2>
                <?php if($content):?>
                    <p><?=$content;?></p>
                <?php endif;?>
            </div>
        </div>
        <div class="row g-5 py-5 justify-content-center">
            <div class="col-12 col-lg-10 mx-auto">
                <div class="row g-4 justify-content-center">
                    <?php
                    foreach( $cpt as $post ): 
                    setup_postdata($post);
                    ?>
                        <?php if($design == 0):?>
                            
                            <div class="<?= $size_xs . ' ' . $size_sm . ' ' . $size_md . ' ' . $size_lg . ' ' . $size_xl;?>">
                                <a href="<?php the_permalink($post); ?>">
                                    <div class="card h-100 shadow">
                                        <div class="card-header bg-transparent border-0 mt-2 text-center">
                                            <?php if ( has_post_thumbnail($post) ):?>
                                                <?php echo get_the_post_thumbnail( $post, 'card-post', array( 'class' => 'img-fluid' ) );?>
                                            <?php else :?>
                                            <img class="card-img-top"
                                                src="https://via.placeholder.com/500x333/cccccc/424242?text=<?php echo get_bloginfo('name');?>"
                                                alt="<?php the_title(); ?>">
                                            <?php endif; ?>
                                        </div>
                                        <div class="card-body fw-bold text-center text-body">
                                            <span class="fs-4 fw-regular"><?php echo get_the_title($post); ?></span>
                                        </div>
                                    </div>
                                </a>
                            </div>
                        <?php elseif($design == 1):
                            $excerpt = get_field('excerpt_content', $post);?>
                            <div class="<?= $size_xs . ' ' . $size_sm . ' ' . $size_md . ' ' . $size_lg . ' ' . $size_xl;?>">
                                <a href="<?php the_permalink($post); ?>">
                                    <div class="card h-100 shadow overflow-hidden">
                                        <?php if ( has_post_thumbnail($post) ):?>
                                            <?php echo get_the_post_thumbnail( $post, 'card-post', array( 'class' => 'img-fluid card-img-top' ) );?>
                                        <?php else :?>
                                        <img class="card-img-top"
                                            src="https://via.placeholder.com/500x333/cccccc/424242?text=<?php echo get_bloginfo('name');?>"
                                            alt="<?php the_title(); ?>">
                                        <?php endif; ?>
                                        <div class="card-body text-center text-lg-start text-body">
                                            <span class="d-block fs-4 fw-regular fw-bold text-body"><?php echo get_the_title($post); ?></span>
                                            <?=$excerpt;?>
                                        </div>
                                    </div>
                                </a>
                            </div>
                        <?php elseif($design == 2):
                            $excerpt = get_field('excerpt_content', $post);?>
                            <div class="<?= $size_xs . ' ' . $size_sm . ' ' . $size_md . ' ' . $size_lg . ' ' . $size_xl;?>">
                                <a href="<?php the_permalink($post); ?>">
                                    <div class="card h-100 shadow overflow-hidden">
                                        <div class="card-header bg-transparent border-0 mt-2">
                                            <div class="row g-3 align-items-center">
                                                <div class="col-auto" style="width:60px">
                                                    <?php if ( has_post_thumbnail($post) ):?>
                                                        <?php echo get_the_post_thumbnail( $post, 'thumbnail', array( 'class' => 'img-fluid' ) );?>
                                                    <?php else :?>
                                                    <img class="card-img-top"
                                                        src="https://via.placeholder.com/500x333/cccccc/424242?text=<?php echo get_bloginfo('name');?>"
                                                        alt="<?php the_title(); ?>">
                                                    <?php endif; ?>
                                                </div>
                                                <div class="col">
                                                    <span class="h3 fs-5 l fw-regular text-body fw-bold"><?php echo get_the_title($post); ?></span>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="card-body text-center text-lg-start text-body">
                                            <?=$excerpt;?>
                                        </div>
                                    </div>
                                </a>
                            </div>
                        <?php elseif($design == 3):
                            $excerpt = get_field('excerpt_content', $post);?>
                            <div class="<?= $size_xs . ' ' . $size_sm . ' ' . $size_md . ' ' . $size_lg . ' ' . $size_xl;?>">
                                <a href="<?php the_permalink($post); ?>">
                                    <div class="card h-100 shadow overflow-hidden">
                                        <div class="card-header bg-transparent border-0 mt-2">
                                            <div class="row g-3 align-items-center">
                                                <div class="col">
                                                    <span class="h3 fs-4 text-body fw-bold"><?php echo get_the_title($post); ?></span>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="card-body text-center text-lg-start text-body">
                                            <?=$excerpt;?>
                                        </div>
                                    </div>
                                </a>
                            </div>
                        <?php endif;?>
                    <?php endforeach;
                    wp_reset_postdata();?>
                </div>
            </div>
        </div>
        <?=$custom;?>
    </div>
</div>
