<?php

/**
 * Template part for displaying content on posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

// Blog ID
$blog_ID = get_option('page_for_posts');

// Options - Theme Settings
$default_featured_image = get_field('blog_default_featured_image', 'option');

// CTAs
$content_cta_source = get_field('content_cta_source', $blog_ID);
$sidebar_cta_source = get_field('sidebar_cta_source', $blog_ID);
$newsletter_cta_source = get_field('newsletter_cta_source', $blog_ID);


// Post - WP
$title = get_the_title();
if (has_post_thumbnail($post->ID)) {
    $featured_image = get_the_post_thumbnail(get_the_ID(), 'header-banner', array('class' => 'rounded img-fluid'));
};

// Post - ACF
$essentials_section = get_field('essentials_section');
$featured_content_format = get_field('featured_content_format');
$featured_video_youtube_ID = get_field('featured_video_youtube_ID');
$h1 = get_field('h1');
$h2 = get_field('h2');
$content = get_the_content();
$category = get_the_category();
$category_url = esc_url(get_category_link($category[0]->term_id));
$lead = get_field('lead');
$authorID = get_the_author_meta('ID');
$avatar = get_field('avatar', 'user_' . $authorID);
$size = "thumbnail";
$image = wp_get_attachment_image_src($avatar, $size);
$pageLink = get_field('pageLinkTeam', 'user_' . $authorID);
$author_name = get_author_name();

// Functions
// Read Time
$count_words = str_word_count(strip_tags($content));
$read_time = ceil($count_words / 250);
?>
<!-- add after bootstrap.min.js or bootstrap.bundle.min.js -->
<style>
    a.breadcrumb-item {
        color: var(--gray-color);
        font-weight: bold;
    }

    a.breadcrumb-item:hover {
        color: black;
    }

    /* Article Typography */
    article p,
    article ul,
    article ol {
        font-size: calc(.95rem + .25vw);
        line-height: 1.75;
        color: rgb(46, 71, 93)
    }

    article h2 {
        font-size: calc(1.75rem + .25vw);
        font-weight: bold;
        margin: 64px 0px 16px 0px;
    }

    article h2:before {
        content: '';
        margin-bottom: 1rem;
        width: 50px;
        height: 3px;
        display: block;
        background: var(--bs-dark);
    }

    article h3 {
        font-size: 1.5rem;
        font-weight: 500;
        line-height: 1.42;
        margin: 32px 0px 16px 0px;
    }

    /* Post - Share */
    #author {
        position: sticky;
        top: <?php the_field('headerHeight', 'option');
                ?>px;
        margin-top: 1rem
    }

    #featuredImage {
        z-index: 2;
        max-height: 40vh;
    }

    #share i {
        border-radius: 0rem;
        display: inline-block;
        color: <?php the_field('colorGray', 'option');
                ?>;
        font-size: 1rem;
        padding: 1rem 1.5rem;
        text-align: center;
        transition: .1s;
    }

    article.post main,
    article.post footer {
        margin-left: 0rem;
        margin-right: 0rem;
    }

    div#share {
        text-align: center;
    }

    #comments p.form-submit {
        text-align: right;
    }

    /* Comments */
    label {
        display: block;
    }

    /* TOC */
    nav[data-toggle=toc] .nav-link.active,
    nav[data-toggle=toc] .nav-link.active:focus,
    nav[data-toggle=toc] .nav-link.active:hover {
        color: black !important;
        font-weight: bold !important;
        border-left: 2px solid #000 !important;
        background: var(--bs-light)
    }

    nav[data-toggle=toc] .nav>li>a:focus,
    nav[data-toggle=toc] .nav>li>a:hover {
        color: #000 !important;
    }
</style>
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.4/jquery.min.js"></script>
<link rel="stylesheet" href="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.css" />
<!-- add after bootstrap.min.js or bootstrap.bundle.min.js -->
<script src="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.js"></script>
<div class="hero position-relative">
    <div class="container">
        <div class="row">
            <div class="col my-4 small text-muted">
                <div class="breadcrumb align-items-center m-0">
                    <a class="breadcrumb-item" href="<?= get_post_type_archive_link('post'); ?>">Blog</a>
                    <?php
                    $category = get_the_category();
                    $first_category = $category[0];
                    echo sprintf('<a class="breadcrumb-item" href="%s">%s</a>', get_category_link($first_category), $first_category->name);
                    ?> <span class="breadcrumb-item"><?= get_the_title(); ?></a>
                </div>
            </div>
        </div>
    </div>
    <div class="container">
        <div class="row align-items-center py-5 g-5">
            <div id="featured-content" class="col-12 col-md-6 mt-0">
                <?php
                if (!empty($featured_video_youtube_ID)) : ?>
                    <div class="video-responsive" style="position: relative; width: 100%; height: 0; padding-bottom: 56.25%;">
                        <iframe src="https://www.youtube.com/embed/<?php the_field('featured_video_youtube_ID'); ?>?rel=0" width="100%" height="100%" frameborder="0" allowfullscreen style="position: absolute; top: 0; left: 0; width: 100%; height: 100%;"></iframe>
                    </div>
                <?php elseif ($featured_image) : ?>
                    <?= $featured_image; ?>
                    <img src="<?= $featured_image[0]; ?>" class="rounded" alt="" width="100%" />
                <?php else : ?>
                    <img src="<?php echo esc_url($default_featured_image['url']); ?>" class="rounded" alt="<?php echo esc_attr($default_featured_image['alt']); ?>" width="100%" />
                <?php endif; ?>
            </div>
            <div class="col-12 col-md-6">
                <a class="fs-6 text-primary btn btn-sm btn-light text-dark mb-4" href="<?= $category_url; ?>"><?= $category[0]->name; ?></a>
                <h1><?php if ($h1) {
                        echo $h1;
                    } else {
                        echo $title;
                    }; ?></h1>
                <?php if ($h2) : ?>
                    <h2 class="lead fw-normal mb-3"><?= $h2; ?></h2>
                <?php endif; ?>
                <div class="row g-2 mt-4">
                    <div class="col text-middle text-lg-start d-flex justify-content-between align-items-center">
                        <?php if($avatar || $author_name){ ?> 
                            <span class="author-info">
                            <?php if($avatar):?>
                            <span>
                                <?php if($pageLink):?>
                                    <a href="<?php echo $pageLink ;?>">
                                        <img alt="<?php the_author();?> Avatar" class="avatar avatar-lg me-2"
                                    src="<?php echo $image[0];?>">
                                    </a>
                                <?php else:?>
                                    <img alt="<?php the_author();?> Avatar" class="avatar avatar-lg me-2" src="<?php echo $image[0];?>">
                                <?php endif;?>
                            </span>
                            <?php endif;?>
                            <?php if($author_name);{ ?> 
                                <span class="text-muted">
                                    <?php echo $author_name;?>  
                            </span>
                            <?php } ?>
                            </span>
                        <?php } ?>
                        <span class="text-muted">
                            <?php the_date('F j, Y'); ?>
                        </span>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<div class="container">
    <div class="row g-5 justify-content-center">
        <div id="table-of-contents" class="col-md-3 d-none d-xl-block">
            <div id="table-of-contents-card" class="card sticky-top overflow-hidden" style="top:10%">
                <div class="card-header font-bold text-secondary font-header bg-transparent">
                    <i class="icon-bookmark-o text-primary"></i> Table of Contents
                    <script>
                        var h = document.getElementById('header').clientHeight;
                        document.getElementById("table-of-contents-card").style.top = h + 15 + 'px';
                    </script>
                </div>
                <div class="my-2">
                    <nav id="toc" data-toggle="toc"></nav>
                </div>
            </div>
        </div>
        <div class="col">
            <div class="row ">
                <div class="col text-muted text-start">
                    <i class="icon-clock"></i> <?php echo $read_time; ?> min read
                </div>
                <div id="share" class="col-auto text-end">

                    <div id="share">
                        <a class="btn btn-sm btn-light" href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>&quote=<?php the_title(); ?>" title="Share on Facebook" target="_blank">
                            <span class="icon-facebook"></span>
                        </a>
                        <a class="btn btn-sm btn-light" target="_new" href="https://twitter.com/intent/tweet?text=<?php echo urlencode(substr(get_the_title(), 0, 79)); ?>&url= <?php echo urlencode(get_permalink()); ?>">
                            <span class="icon-twitter"></span>
                        </a>
                        <a class="btn btn-sm btn-light" href="http://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink(); ?>&title=<?php the_title(); ?>" target="_blank" title="Share on LinkedIn">
                            <span class="icon-linkedin"></span>
                        </a>
                        <a class="btn btn-sm btn-light" href="mailto:?subject=<<?php the_title(); ?>>&body=<<?php the_permalink(); ?>>" target="_blank">
                            <span class="icon-envelope"></span>
                        </a>
                    </div>
                </div>
            </div>
            <hr>
            <article id="post-<?php the_ID(); ?>" <?php post_class('toc'); ?> data-bs-spy="scroll" data-bs-target="#toc">
                <div id="article" class="mb-5" data-bs-spy="scroll" data-bs-target="#toc" data-bs-offset="0" tabindex="0">
                    <?= $content; ?>
                </div>
            </article><!-- #post-<?php the_ID(); ?> -->



        </div>
        <div class="col-12 col-lg-3 ">
            <div id="sidebar-ctas" class="sticky-top">
                <?php
                // Sidebar CTA
                // first check if there's a Sidebar CTA
                if ($sidebar_cta_source) { ?>
                <div class="sidebar-cta mb-4 text-center">
                            <?php
                            if ($sidebar_cta_source == 'custom') {
                                the_field('sidebar_cta_html', $blog_ID);
                            } else {
                                if ($sidebar_cta_source == 'templated') {
                                    $args = array(
                                        'cta_prefix' => 'sidebar_cta_fields_',
                                        'sourceID'   => get_option('page_for_posts')
                                    );
                                } else {
                                    $args = array(
                                        'cta_prefix' => $sidebar_cta_source,
                                        'sourceID'   => 'option'
                                    );
                                }

                                get_template_part('/template-parts/' . get_field('template', 'option') . '/inc/cta/global-cta-sm', '', $args);
                            }
                            ?>
                    </div>
                <?php } ?>


                <?php
                // Newsletter CTA
                // first check if there's a Newsletter CTA
                if ($newsletter_cta_source) { ?>
                    <?php
                    if ($newsletter_cta_source == 'custom') {
                        the_field('newsletter_cta_html', $blog_ID);
                    } else {
                        include get_template_directory() . '/template-parts/' . get_field('template', 'option') . '/inc/cta/newsletter.php';
                    }
                    ?>
                <?php } ?>
            </div>
            <script>
                var h = document.getElementById('header').clientHeight;
                document.getElementById("sidebar-ctas").style.top = h + 15 + 'px';
            </script>
        </div>

    </div>
</div>
<div class="container py-5">
    <div class="row justify-content-center">
        <div class="col-12 col-md-10 col-lg-8">
            <div class="card bg-secondary-light-hover py-0 px-4" style="background-image: url('https://memberclickdev.wpengine.com/wp-content/uploads/2023/08/Vector-4-4.png'); background-position: right bottom; background-repeat: no-repeat">
                <div class="card-body py-0">
                    <div class="row align-items-center justify-content-center">
                        <div class="col-12 col-lg-5 order-lg-1 text-center">
                            <img class="img-fluid mx-auto" src="https://memberclickdev.wpengine.com/wp-content/uploads/2023/07/MC-MemRetention-Mockup-1-1.png">
                        </div>
                        <div class="col-12 col-lg-7 order-lg-0 py-3 text-center text-lg-start">
                            <span class="h4 text-dark fw-bold">Free Member Retention Guide</span>
                            <p class="text-light">Ready to retain members and keep them coming back forever and ever? This guide will teach you everything you need to know about member retention. We cover all the basics, like the first steps to member retention and how to map out your member journey. From there, we dive a bit deeper into retention tips.</p>
                            <a class="btn btn-secondary" href="/resources/guides/member-retention-101/">Download</a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<?php
// Content CTA
// first check if there's a Content CTA
// if ($content_cta_source) { 
?>
    <!-- <div class="container">
        <div class="row py-4">
            <?php
            // if ($content_cta_source == 'custom') {
            //     the_field('content_cta_html', $blog_ID);
            // } else {
            //     if ($content_cta_source == 'templated') {
            //         $args = array(
            //             'cta_prefix' => 'content_cta_fields_',
            //             'sourceID'   => get_option('page_for_posts')
            //         );
            //     } else {
            //         $args = array(
            //             'cta_prefix' => $content_cta_source,
            //             'sourceID'   => 'option'
            //         );
            //     }

            //     get_template_part('/template-parts/' . get_field('template', 'option') . '/inc/cta/global-cta', '', $args);
            // }
            ?>
        </div>
    </div> -->
<?php
// } 
?>