<?php
/**
 * @param WP_Query|null $wp_query
 * @param bool $echo
 * @param array $params
 *
 * @return string|null
 * 
 * Accepts a WP_Query instance to build pagination (for custom wp_query()),
 * or nothing to use the current global $wp_query (eg: taxonomy term page)
 * - Tested on WP 5.4.1
 * - Tested with Bootstrap 5.0
 * - Tested on Sage 9.0.9
 *
 */
function pixelnet_bootstrap_pagination( $wp_query = false, $echo = true, $args = array() ) {
    //Fallback to $wp_query global variable if no query passed
    if ( false === $wp_query ) {
        global $wp_query;
    }

    //Set Defaults
    $defaults = array(
        'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
        'format'       => '?paged=%#%',
        'current'      => max( 1, get_query_var( 'page' ) ),
        'total'        => $wp_query->max_num_pages,
        'type'         => 'array',
        'show_all'     => false,
        'end_size'     => 2,
        'mid_size'     => 1,
        'prev_text'    => __( '« Prev' ),
        'next_text'    => __( 'Next »' ),
        'add_fragment' => '',
    );
     
    //Merge the defaults with passed arguments
    $merged = wp_parse_args( $args, $defaults );
     
    //Get the paginated links
    $lists = paginate_links($merged);
 
    if ( is_array( $lists ) ) {
         
        $html = '<nav><ul class="pagination justify-content-center">';
 
        foreach ( $lists as $list ) {
            $html .= '<li class="page-item' . (strpos($list, 'current') !== false ? ' active' : '') . '"> ' . str_replace('page-numbers', 'page-link text-dark', $list) . '</li>';
        }
 
        $html .= '</ul></nav>';
 
        if ( $echo ) {
            echo $html;
        } else {
            return $html;
        }
    }
     
    return false;
}

function bootstrap_pagination( \WP_Query $wp_query = null, $echo = true, $params = [] ) {
    if ( null === $wp_query ) {
        global $wp_query;
    }

    $add_args = [];

    //add query (GET) parameters to generated page URLs
    /*if (isset($_GET[ 'sort' ])) {
        $add_args[ 'sort' ] = (string)$_GET[ 'sort' ];
    }*/




    $pages = paginate_links( array_merge( [
            'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
            'format'       => '?paged=%#%',
            'current'      => max( 1, get_query_var( 'paged' ) ),
            'type'         => 'array',
            'show_all'     => false,
            'end_size'     => -1,
            'mid_size'     => 1,
            'prev_next'    => true,
            'prev_text'    => __( '«<span class="d-none d-md-inline"> Prev</span>' ),
            'next_text'    => __( '<span class="d-none d-md-inline">Next </span>»' ),
            'add_args'     => $add_args,
            'add_fragment' => ''
        ], $params )
    );

    if ( is_array( $pages ) ) {
        //$current_page = ( get_query_var( 'paged' ) == 0 ) ? 1 : get_query_var( 'paged' );
        $pagination = '<div class="pagination py-4 my-4"><ul class="pagination">';

        foreach ( $pages as $page ) {
            $pagination .= '<li class="page-item mx-1' . (strpos($page, 'current') !== false ? ' active' : '') . '"> ' . str_replace('page-numbers', 'page-link small', $page) . '</li>';
        }

        $pagination .= '</ul></div>';

        if ( $echo ) {
            echo $pagination;
        } else {
            return $pagination;
        }
    }

    return null;
};

/* Breadcrumbs */
require_once('inc/breadcrumbs.php');

/* Post - Limit Excerpt Length*/
function get_excerpt($limit, $source = null){

    $excerpt = $source == "content" ? get_the_content() : get_the_excerpt();
    $excerpt = preg_replace(" (\[.*?\])",'',$excerpt);
    $excerpt = strip_shortcodes($excerpt);
    $excerpt = strip_tags($excerpt);
    $excerpt = substr($excerpt, 0, $limit);
    $excerpt = substr($excerpt, 0, strripos($excerpt, " "));
    $excerpt = trim(preg_replace( '/\s+/', ' ', $excerpt));
    $excerpt = $excerpt.'... <a href="'.get_permalink($post->ID).'">Read More</a>';
    return $excerpt;
}

/* Sidebar */
function has_children() {
    global $post;

    $children = get_pages( array( 'child_of' => $post->ID ) );
    if( count( $children ) == 0 ) {
        return false;
    } else {
        return true;
    }
}

add_image_size( 'team-member', 225, 225, true );

/** WPFORMS
 * Disable the scroll on field validation errors
 *
 *  @link   https://wpforms.com/developers/how-to-disable-the-scrolling-effect-on-field-validation/
 */
 
/** Disable the scrolling effect on field validation errors
 *
 *  @link   https://wpforms.com/developers/how-to-disable-the-scrolling-effect-on-field-validation/
 */
 
function wpf_dev_disable_scroll_to_error( $forms ) {
 
    // If scrollToError is disabled for at least one form on the page, it will be disabled for all the forms on the page.
 
    ?>
    <script type="text/javascript">wpforms.scrollToError = function(){};</script>
    <?php
}
add_action( 'wpforms_wp_footer_end', 'wpf_dev_disable_scroll_to_error', 10, 1 );

/* Register Navigation Walker for Mobile Menu */
function register_navwalkerMobile(){
    require_once get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/inc/navwalker-mobile.php';
}
add_action( 'after_setup_theme', 'register_navwalkerMobile' );

/* Register Navigation Walker for Sidebar */
function register_navwalkerSidebar(){
    require_once get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/inc/navwalker-sidebar.php';
}
add_action( 'after_setup_theme', 'register_navwalkerSidebar' );

/* Register Navigation Walker for Sitemap */
function register_navwalkerSitemap(){
    require_once get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/inc/navwalker-sitemap.php';
}
add_action( 'after_setup_theme', 'register_navwalkerSitemap' );

/* GET FILE WITH SHORTCODE */
function include_file($atts) {
    $a = shortcode_atts( array(
       'slug' => 'NULL',
      ), $atts );

       ob_start();
       include get_template_directory() . '/template-parts/'. get_field('template', 'option') . $a['slug'];
       return ob_get_clean();
}

add_shortcode('include', 'include_file');

function my_acf_format_value( $value, $post_id, $field ) {

    // Render shortcodes in all textarea values.
    return do_shortcode( $value );
}

// Apply to all fields.
// add_filter('acf/format_value', 'my_acf_format_value', 10, 3);

// Apply to textarea fields.
// add_filter('acf/format_value/type=textarea', 'my_acf_format_value', 10, 3);

// Apply to fields named "hero_text".
 add_filter('acf/format_value/name=page_content', 'my_acf_format_value', 10, 3);

// Apply to field with key "field_123abcf".
// add_filter('acf/format_value/key=field_123abcf', 'my_acf_format_value', 10, 3);

add_filter('post_type_link', 'projectcategory_permalink_structure', 10, 4);
function projectcategory_permalink_structure($post_link, $post, $leavename, $sample) {
    if (false !== strpos($post_link, '%resource_type%')) {
        $projectscategory_type_term = get_the_terms($post->ID, 'resource_type');
        if (!empty($projectscategory_type_term))
            $post_link = str_replace('%resource_type%', array_pop($projectscategory_type_term)->
            slug, $post_link);
        else
            $post_link = str_replace('%resource_type%', 'uncategorized', $post_link);
    }
    return $post_link;
}