<?php
/**
 * Template Name: Sitemap
 * The template for displaying the sitemap
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

get_header();

$privacyPolicy = get_template_page_url('privacy-policy.php');
$terms = get_template_page_url('terms.php');
$cookie = get_template_page_url('cookie.php');
$sitemap = get_template_page_url('sitemap.php');
$excludePages = get_field('pages_to_exclude');
$exclude = implode(',', $excludePages);

?>
<style>
#resourcesMenu {
	border-right: 1px solid #e5e5e5; 
}
#resourcesMenu a {
	color: #999999;
}
#resourcesMenu a:hover {
	color: #000000;
}
#sitemap ul {
	margin-left: 0px
}
#sitemap ul.children {
    margin: 0rem 0rem 0rem 1rem;
    border-left: 1px solid #eee;
}
#sitemap li {
	list-style-type: none;
	margin: 0px;
}
#sitemap li a:hover{
	background: #ffffff;
}
#sitemap li a{
	color: #999999;
	display: block;
	padding: 5px 0px;
	width: 100%;
	transition: .3s;
}
#sitemap li a:hover{
	color: #000000;
}
#sitemap li a:after{
	content: '\203A';
	opacity: 0;
	transition: .3s;
}
#sitemap li a:hover:after{
	content: '\203A';
	opacity: 1;
	margin-left: .5rem;
}
#resourcesMenu .sitemap {
	color: #000;
}
</style>
<div id="main-container" class="content-area">
	<section>
		<div class="container grid-xl">
			<div class="columns">
				<div class="column col-12">
					<?php if(!is_front_page()): ?>
						<?php get_breadcrumb(); ?>
					<?php endif; ?>
				</div>
			</div>
		</div>
	</section>
	<section>
		<div class="container grid-xl p-relative">
			<div class="columns">
				<div class="column col-12">
					<div class="divider m-0"></div>
				</div>
				<div id="resourcesMenu" class="column col-3 hide-md">
					<div class="p-sticky py-layout">
						<div class="text-bold">Resources</div>
						<div class="small mb-layout">
							<?php if($privacyPolicy){
								echo '<a class="d-block privacy" href="' . $privacyPolicy . '">Privacy Policy</a>';
							};?>
							<?php if($terms){
								echo '<a class="d-block terms" href="' . $terms . '">Terms and Conditions</a>';
							};?>
							<?php if($cookie){
								echo '<a class="d-block cookie" href="' . $cookie . '">Cookie Policy</a>';
							};?>
						</div>
						<div class="small">
							<?php if($sitemap){
								echo '<a class="d-block sitemap" href="' . $sitemap . '">Sitemap</a>';
							};?>
						</div>
					</div>
				</div>
				<div class="column col-9 col-md-12 pt-layout">
					<article id="sitemap">
						<main id="main" class="site-main">
							<h1>Sitemap</h1>
							<?php the_content();?>
							<h3 id="pages" class="mt-layout">Pages</h3>
							<div class="divider"></div>
							<ul>
								<?php wp_list_pages( 'exclude=' . $exclude . '&sort_column=menu_order&title_li=' ); ?>
							</ul>
							<?php foreach( get_post_types( array('public' => true, '_builtin' => false) ) as $post_type ) {
								//Retrieves an object which describes any registered post type: 
								//in this case only user-created Custom Post Type
								$cpt = get_post_type_object( $post_type );
								$excludeCPT = array( 'awards', 'testimonials' ); //Exclude Custom Post Types
								if( TRUE === in_array( $cpt->name, $excludeCPT ) )
								continue;
								echo '<div class="column col-3 col-lg-4 col-md-6 col-sm-12 my-layout">';
								echo '<h3>'.$cpt->labels->name.'</h3>';
								echo '<div class="divider"></div>';
								echo '<ul>';
								$args = array(
									'post_type' => $post_type,
									'exclude' => array($excludeID), /**Exclude custom posts by ID separated by comma inside the array.**/
									'posts_per_page' => -1  //show all custom posts
								);
								$query_cpt = new WP_Query($args);
								
								while( $query_cpt->have_posts() ) {
									$query_cpt->the_post();
									echo '<li><a title="'.get_the_title().'" href="'.get_permalink().'">'.get_the_title().'</a></li>';
								}
								echo '</ul>';
								echo '</div>';
								} 
							?> 
							<?php 
							$args = array(
								'post_type'=> 'post',
								'orderby'    => 'ID',
								'post_status' => 'publish',
								'order'    => 'DESC',
								'posts_per_page' => -1,
								'category__not_in' => array(57),
								);
							$result = new WP_Query( $args );
							if ( $result-> have_posts() ) : ?>
								<div class="column col-12 my-layout">
									<h3>Posts</h3>
									<div class="divider"></div>
										<ul>
											<div class="columns">
												<?php while ( $result->have_posts() ) : 
												$result->the_post(); ?>
													<div class="column col-3 col-lg-4 col-md-6 col-sm-12">
														<li>
															<a href="<?php the_permalink();?>"><?php the_title(); ?></a>
														</li>
													</div>
												<?php endwhile; ?>
											</div>
										</ul>
									</div>
								</div>
							<?php endif; 
							wp_reset_postdata(); ?>
						</main>
					</article>
				</div>
			</div>
	</section>
</div>
<?php

get_footer();
