<?php
/**
 * Template part for displaying content on posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

// Options - Theme Settings
$default_featured_image = get_field('blog_default_featured_image', 'option');

// Post - WP
$title = get_the_title();
$featuredImage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'medium' );

// Post - ACF
$essentials_section = get_field('essentials_section');
$featured_image = get_field('featured_image');
$featured_content_format = get_field('featured_content_format');
$featured_video_youtube_ID = get_field('featured_video_youtube_ID');
$h1 = get_field('h1');
$h2 = get_field('h2');
$content = get_field('content');
$category = get_the_category();
$category_url = esc_url( get_category_link( $category[0]->term_id ) );

if (has_post_thumbnail( $post->ID )) {
	$featuredImage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'header-banner' );
	$thumbnail_id = get_post_thumbnail_id( $post->ID );
	$alt = get_post_meta($thumbnail_id, '_wp_attachment_image_alt', true);
}
$lead = get_field('lead');
$authorID = get_the_author_meta('ID');
$avatar = get_field('avatar', 'user_' . $authorID);
$size = "thumbnail";
$image = wp_get_attachment_image_src( $avatar, $size );
$pageLink = get_field('pageLinkTeam', 'user_' . $authorID);

// Functions
    // Read Time
    $count_words = str_word_count( strip_tags( $content ) );
    $read_time = ceil($count_words / 250);
?>
<style>
    a.breadcrumb-item {
        color: var(--gray-color);
        font-weight: bold;
    }
    a.breadcrumb-item:hover {
        color: black;
    }
    /* Article Typography */
    article p,
    article ul,
    article ol {
        font-size: calc(.95rem + .25vw);
        line-height: 1.75;
        color: rgb(46,71,93)
    }
    article h2 {
        font-size: calc(1.75rem + .25vw);
        font-weight: bold;
        margin: 64px 0px 16px 0px;
    }
    article h2:before {
        content: '';
        margin-bottom: 1rem;
        width: 50px;
        height: 3px;
        display: block;
        background: var(--bs-dark);
    }
    article h3 {
        font-size: 1.5rem;
        font-weight: 500;
        line-height: 1.42;
        margin: 32px 0px 16px 0px;
    }
    /* Post - Share */
    #author {
        position: sticky;
        top: <?php the_field('headerHeight', 'option');
        ?>px;
        margin-top: 1rem
    }

    #featuredImage {
        z-index: 2;
        max-height: 40vh;
    }

    #share i {
        border-radius: 0rem;
        display: inline-block;
        color: <?php the_field('colorGray', 'option');
        ?>;
        font-size: 1rem;
        padding: 1rem 1.5rem;
        text-align: center;
        transition: .1s;
    }

    article.post main,
    article.post footer {
        margin-left: 0rem;
        margin-right: 0rem;
    }

    div#share {
        text-align: center;
    }
    #comments p.form-submit {
        text-align: right;
    }

    /* Comments */
    label {
        display: block;
    }

    /* TOC */
    nav[data-toggle=toc] .nav-link.active, nav[data-toggle=toc] .nav-link.active:focus, nav[data-toggle=toc] .nav-link.active:hover {
        color: black !important;
        font-weight: bold !important;
        border-left: 2px solid #000 !important;
        background: var(--bs-light)
    }
    nav[data-toggle=toc] .nav>li>a:focus, nav[data-toggle=toc] .nav>li>a:hover {
        color: #000 !important;
    }
</style>
<link rel="stylesheet" href="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.css"
/>
<!-- add after bootstrap.min.js or bootstrap.bundle.min.js -->
<script src="https://cdn.rawgit.com/afeld/bootstrap-toc/v1.0.1/dist/bootstrap-toc.min.js"></script>
<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
    <div class="hero position-relative">
        <div class="container">
            <div class="row">
                <div class="col my-4 small text-muted">
                    <div class="breadcrumb align-items-center">
                        <a class="breadcrumb-item" href="<?=get_post_type_archive_link( 'post' );?>">Blog</a><?php
    $category = get_the_category();
    $first_category = $category[0];
    echo sprintf( '<a class="breadcrumb-item" href="%s">%s</a>', get_category_link( $first_category ), $first_category->name );
    ?> <span class="breadcrumb-item"><?=get_the_title();?></a>
                    </div>
                </div>
            </div>
        </div>
        <div class="container-fluid container-xl">
            <div class="row align-items-center py-5 g-5">
                <div id="featured-content" class="col-12 col-md-6">
                    <?php 
                    if( !empty( $featured_video_youtube_ID ) ): ?>
                        <div class="video-responsive" style="position: relative; width: 100%; height: 0; padding-bottom: 56.25%;">
                            <iframe src="https://www.youtube.com/embed/<?php the_field('featured_video_youtube_ID'); ?>?rel=0" width="100%" height="100%" frameborder="0" allowfullscreen style="position: absolute; top: 0; left: 0; width: 100%; height: 100%;"></iframe>
                        </div>
                    <?php elseif($featuredImage): ?>
                        <img src="<?php echo esc_url($featured_image['url']); ?>" class="rounded" alt="<?php echo esc_attr($featured_image['alt']); ?>" width="100%" />
                    <?php else:?>
                        <img src="<?php echo esc_url($default_featured_image['url']); ?>" class="rounded" alt="<?php echo esc_attr($default_featured_image['alt']); ?>" width="100%" />
                    <?php endif;?>
                </div>
                <div class="col-12 col-md-6 text-center text-md-start">
                    <a class="fs-6 text-primary btn btn-sm btn-light text-dark mb-4" href="<?= $category_url;?>"><?= $category[0]->name ;?></a>
                    <h1><?php if($h1){
                        echo $h1;
                    } else {
                        echo $title;
                    };?></h1>
                    <?php if($h2):?>
                    <h2 class="lead fw-normal mb-3"><?= $h2;?></h2>
                    <?php endif;?>
                    <div class="row justify-content-center align-items-center g-2 mt-4">
                        <div class="col text-middle text-lg-start">
                            <div class="small">
                                <div class="text-muted">
                                        Author: <?php the_author();?>
                                </div>
                                <div class="text-muted">
                                    <?php the_date('F j, Y');?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="container grid-xl my-3">
        <div class="row g-5 justify-content-center">
            <div id="table-of-contents" class="col-12 col-md-2 col-lg-4 col-xl-4 d-none d-lg-block">
                <div id="table-of-contents-card" class="card sticky-top overflow-hidden" style="top:10%">
                    <div class="card-header small text-uppercase text-muted">
                        Contents
                        <script>var h = document.getElementById('header').clientHeight;
                        document.getElementById("table-of-contents-card").style.top = h + 15 + 'px';</script>
                    </div>
                    <div class="my-2">
                        <nav id="toc" data-toggle="toc"></nav>
                    </div>
                </div>
            </div>
            <div class="col-12 col-md-10 col-lg-8 col-xl-8">
                <div class="row">
                    <div class="col text-muted text-start">
                        🕑 <?php echo $read_time;?> min read 
                    </div>
                    <div id="share" class="col-auto text-end">
                        
                        <div id="share">
                            <a class="btn btn-sm btn-light"
                                href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink();?>&quote=<?php the_title(); ?>"
                                title="Share on Facebook" target="_blank">
                                <span class="icon-facebook"></span>
                            </a>
                            <a class="btn btn-sm btn-light" target="_new"
                                href="https://twitter.com/intent/tweet?text=<?php echo urlencode(substr(get_the_title(), 0, 79));?>&url= <?php echo urlencode(get_permalink());?>">
                                <span class="icon-twitter"></span>
                            </a>
                            <a class="btn btn-sm btn-light"
                                href="http://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink();?>&title=<?php the_title();?>"
                                target="_blank" title="Share on LinkedIn">
                                <span class="icon-linkedin"></span>
                            </a>
                            <a class="btn btn-sm btn-light"
                                href="mailto:?subject=<<?php the_title();?>>&body=<<?php the_permalink();?>>"
                                target="_blank">
                                <span class="icon-envelope-o"></span>
                            </a>
                        </div>
                    </div>
                </div>
                <hr>
                <div id="content" class="mb-5" data-bs-spy="scroll" data-bs-target="#toc" data-bs-offset="0" tabindex="0">
                    <?= $content ;?>
                </div>
            </div>
        </div>
</article><!-- #post-<?php the_ID(); ?> -->