<?php
/**
 * Template Name: Single
 * The template for displaying the Single Posts.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

get_header();
// Options - Theme Settings
$service_name = get_field('services_name_plural', 'option');

// Post - WP
$title = get_the_title();
$featuredImage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'header-banner' );

// Post - ACF
$excerpt_format = get_field('excerpt_format');
$excerpt_image_source = get_field('excerpt_image_source');
$excerpt_video_source = get_field('excerpt_video_source');
$excerpt_image = get_field('excerpt_image');
$excerpt_url = get_field('excerpt_url');
$excerpt_video = get_field('excerpt_video');
$excerpt_header = get_field('excerpt_header');
$excerpt_content = get_field('excerpt_content');

$essentials_section = get_field('essentials_section');
$featured_image = get_field('featured_image');
$featured_content_format = get_field('featured_content_format');
$featured_video_youtube_ID = get_field('featured_video_youtube_ID');
$h1 = get_field('h1');
$h2 = get_field('h2');
$content = get_field('content');

$testimonials_section = get_field('testimonials_section');
if ($testimonials_section){
    $testimonials_name_plural = get_field('testimonials_name_plural', 'option');
    $testimonials_source = get_field('testimonials_source');
    $testimonials_heading = get_field('testimonials_heading');
    $testimonials_content = get_field('testimonials_content');
    $testimonials_service = get_field('testimonials_service');
};

?>

</style>
<main>
	<?php if($essentials_section):?>
		<div class="hero position-relative bg-primary-light">
			<div class="container col-12">
				<div class="row align-items-center py-5" style="min-height:50vh">
					<div class="col-lg-6 text-center text-lg-start my-5">
						<span class="fs-6 text-uppercase text-primary"><?= $title ;?></span>
						<h1 class="mb-3"><?= $h1 ;?></h1>
						<?php if($h2):?>
						<h2 class="lead fw-normal mb-3"><?= $h2;?></h2>
						<?php endif;?>
						<div class="row g-3">
							<div class="col-12 text-center text-lg-start">
						<?php if($essentials_button_1):?>
							<a class="btn btn-lg btn-primary d-inline-block mb-3" href="<?php the_field('essentials_button_1_url');?>"><?php the_field('essentials_button_1');?></a>
						<?php endif;?>
<!-- 
CUSTOM CODE START - NOT FOR FINAL
-->
                        <a class="btn btn-cta" href="https://register.wildapricot.com/">Try Now</a>
<!-- 
CUSTOM CODE END
NOT FOR FINAL
-->
							</div>
						</div>
					</div>
					<div id="featured-content" class="col-md-12 col-lg-6">
						<?php 
						if( !empty( $featured_video_youtube_ID ) ): ?>
							<div class="video-responsive" style="position: relative; width: 100%; height: 0; padding-bottom: 56.25%;">
								<iframe src="https://www.youtube.com/embed/<?php the_field('featured_video_youtube_ID'); ?>?rel=0" width="100%" height="100%" frameborder="0" allowfullscreen style="position: absolute; top: 0; left: 0; width: 100%; height: 100%;"></iframe>
							</div>
						<?php else: ?>
							<img src="<?php echo esc_url($featured_image['url']); ?>" alt="<?php echo esc_attr($featured_image['alt']); ?>" width="100%" />
						<?php endif;?>
					</div>
				</div>
			</div>
		</div>
	<?php endif;?>
	<?php 
	// CONTENT BLOCK V.0.1
	$args=array(
		'orderby' => 'menu_order',
		'post_type' => 'services',
		'posts_per_page' => -1,
	);
	$services = get_posts( $args );
	if($services) :?>
		<div class="container py-5">
			<div class="row g-4">
				<div class="col-12">
					<article>
						<?= $content;?>
					</article>
				</div>
			</div>
		</div>
	<?php endif;?>
</main>
<?php if($testimonials_section):?>
    <div id="testimonials" class="bg-secondary">
        <div class="container grid-xl py-5">
            <div class="row my-5">
                <div class="col-12 col-md-6 my-3 text-center text-md-start">
                    <?php if($testimonials_heading):?>
                        <h2 class="text-secondary-contrast display-3 fw-normal"><?= $testimonials_heading;?></h2>
                    <?php endif ;?>
                    <hr class="bg-secondary-contrast d-none d-md-block" style="width:150px; height: 3px">
                    <?php if($testimonials_content):?>
                        <div class="text-secondary-contrast"><?= $testimonials_content;?></div>
                    <?php endif;?>
                    <a class="btn btn-primary" href="<?php echo get_post_type_archive_link('testimonials');?>">View All  <?= $testimonials_name_plural;?></a>
                </div>
                <div class="col-12 col-md-6">
                    <?php 
                    $post = get_post($testimonials_service);
                    setup_postdata($post);
                    ?>
                        <?php include get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/inc/testimonial.php';?>
                    <?php 
                    // Reset the global post object so that the rest of the page works correctly.
                    wp_reset_postdata(); ?>
                </div>
            </div>
        </div>
    </div>
<?php endif;?>
<div id="more-services">
	<div class="container grid-xl my-5">
		<div class="row g-4">
            <?php 
            $categories = get_the_category();
            $category_id = $categories[0]->cat_ID;
            $category_name = get_cat_name($category_id);
            $category_link = get_category_link($category_id);
            $posts = get_posts(array(
                'category'          => $category_id,
                'exclude'           => get_the_ID(),
                'orderby' => 'rand',
                'order'    => 'ASC',
                'posts_per_page'	=> 4,
                'post_type'			=> 'services',
                'post_parent'       => 0,
            ));
            if( $posts ): 
            ?>
                <div class="col-12">
                    <h2>More <?php 
                        echo $service_name
                    ;?></h2>
                </div>
                <?php foreach( $posts as $post ): 
                setup_postdata( $post ); ?>
                    <?php include get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/inc/services.php';?>
                <?php endforeach; ?>
                <?php wp_reset_postdata(); ?>
			<?php endif; ?>
		</div>
	</div><!-- #primary -->
</div>
<!-- 
CUSTOM CODE END
NOT FOR FINAL
-->
<div id="reasons" class="py-5 bg-gray-light">
    <div class="container">
        <div class="row g-4">
            <div class="col-12">
                <h2>Three Reasons to Choose Wild Apricot</h2>
            </div>
            <div class="col-12 col-md-4">
                <div class="card h-100">
                    <div class="card-body">
                        <div class="row align-items-center">
                            <div class="col-12 text-center p-3">
                                <img src="https://wildapricotdev.wpengine.com/wp-content/uploads/2022/09/reasons01-1.png" alt="trophy" height="100px" width="auto">
                            </div>
                            <div class="col lead text-center">
                                Ranked the #1 Membership Management Software
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-12 col-md-4">
                <div class="card h-100">
                    <div class="card-body">
                        <div class="row align-items-center">
                            <div class="col-12 text-center p-3">
                                <img src="https://wildapricotdev.wpengine.com/wp-content/uploads/2022/09/reasons02-1.png" alt="hands" height="100px" width="auto">
                            </div>
                            <div class="col lead text-center">
                                Do it yourself with our easy-to-learn system
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-12 col-md-4">
                <div class="card h-100">
                    <div class="card-body">
                        <div class="row align-items-center">
                            <div class="col-12 text-center p-3">
                                <img src="https://wildapricotdev.wpengine.com/wp-content/uploads/2022/09/reasons03-1.png" alt="hands" height="100px" width="auto">
                            </div>
                            <div class="col lead text-center">
                                Unlimited expert support that's quick and friendly
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<div id="reasons" class="py-5">
    <div class="container">
        <div class="row g-5 align-items-center">
            <div class="col-12 col-md-7">
                <img class="img-fluid" src="https://wildapricotdev.wpengine.com/wp-content/uploads/2022/09/laptop.png" alt="laptop">
            </div>
            <div class="col-12 col-md-5 fs-1">
                Easily manage your members with an online membership database
            </div>
        </div>
    </div>
</div>
<!-- 
CUSTOM CODE END
NOT FOR FINAL
-->
<?php

get_footer();
