<?php
/**
 * Template Name: Sitemap
 * The template for displaying the sitemap
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages
 * and that other 'pages' on your WordPress site may use a
 * different template.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package amp
 */

get_header();

$privacyPolicy = get_template_page_url('privacy-policy.php');
$terms = get_template_page_url('terms.php');
$cookie = get_template_page_url('cookie-policy.php');
$sitemap = get_template_page_url('sitemap.php');
$press = get_template_page_url('press.php');
$brand = get_template_page_url('brand.php');
$excludePages = get_field('pages_to_exclude');
if($excludePages){
	$exclude = implode(",", $excludePages);
};

?>
<style>
	#resourcesMenu a {
		color: #999999;
	}

	#resourcesMenu a:hover,
	#resourcesMenu .current {
		color: #000000;
		background: <?php the_field('color_gray', 'option');
		?>25;
	}

	#resourcesMenu i {
		height: 20px;
		width: 40px;
		text-align: center;
	}

    /* Sitemap */
    #sitemap ol, #sitemap ul {
        margin-left: 1.5rem;
        border-left: 1px solid rgba(0, 0, 0, 0.125);
        padding:0px;
    }
    #sitemap .list-group{
        height: 10rem;
        overflow: hidden;
    }
    #sitemap .card-sitemap.show .list-group {
        height: auto;
        overflow: auto;
    }
    #sitemap .card-sitemap.show .sitemap-show {
        display:none;
    }
    #sitemap a.list-group-item:hover {
        background: var(--gray-color-light);
    }
</style>
<main>
	<div class="container">
		<div class="row">
			<div class="col my-4">
				<?php if(!is_front_page()): ?>
				<?php get_breadcrumb(); ?>
				<?php endif; ?>
			</div>
		</div>
	</div>
	<div class="container mb-4">
		<div class="row g-4">
			<div id="sitemap" class="col-12 col-lg-9 order-lg-2">
				<h1>Sitemap</h1>
				<div class="row g-4">
					<div id="post-type-pages" class="col-12 col-md-6 col-lg-4 card-sitemap">
						<div class="fw-bold lead">Pages</div>
                        <ul class="list-group small position-relative">
                            <?php
                            wp_reset_postdata(); ?>
                            <?php $args = array(
                                'authors' => '',
                                'child_of' => 0,
                                'date_format' => get_option( 'date_format' ),
                                'depth' => 0,
                                'echo' => 1,
                                'exclude' => $exclude,
                                'include' => '',
                                'link_after' => '',
                                'link_before' => '',
                                'post_type' => 'page',
                                'post_status' => 'publish',
                                'show_date' => '',
                                'sort_column' => 'menu_order, post_title',
                                'sort_order' => '',
                                'title_li' => __( '' ),
                                'walker' => new Wdm_Walker_Page()
                            );

                            echo wp_list_pages( $args ) ;?>
                        </ul>
                        <div class="list-group-item btn btn-sm btn-outline-primary mx-4 card-sitemap sitemap-show" data-toggle="collapse" data-target="#post-type-pages" href="">View All</div>
					</div>
                    <?php 
                    foreach( get_post_types( array('public' => true, '_builtin' => false) ) as $post_type ):?>
                        <?php if($post_type !== 'contact'):?>
                        <?php
                        $cpt = get_post_type_object( $post_type )
                        ;?>
                        <div id="post-type-<?php echo $post_type;?>" class="col-12 col-md-6 col-lg-4 mb-4 card-sitemap">
                            <a class="fw-bold lead" href="<?php echo get_post_type_archive_link( $post_type );?>"><?php echo $cpt->labels->name;?></a>
                                <?php
                                wp_reset_postdata(); ?>
                                <?php $args = array(
                                    'authors' => '',
                                    'child_of' => 0,
                                    'date_format' => get_option( 'date_format' ),
                                    'depth' => 0,
                                    'echo' => 1,
                                    'exclude' => $exclude,
                                    'include' => '',
                                    'link_after' => '',
                                    'link_before' => '',
                                    'post_type' => $post_type,
                                    'post_status' => 'publish',
                                    'show_date' => '',
                                    'sort_column' => 'menu_order, post_title',
                                    'sort_order' => '',
                                    'title_li' => __( '' ),
                                    'walker' => new Wdm_Walker_Page()
                                );
                                $number = count(get_pages($args));
                                if($number < 4):?>
                                    <ul class="list-group small position-relative">
                                        <?php echo wp_list_pages( $args );?>
                                    </ul>
                                <?php else:?>
                                    <ul class="list-group small">
                                        <?php echo wp_list_pages( $args );?>
                                    </ul>
                                    <div class="list-group-item btn btn-sm btn-outline-primary mx-4 card-sitemap sitemap-show" data-toggle="collapse" data-target="#post-type-<?php echo $post_type;?>" href="">View All</div>
                                <?php endif;?>
                        </div>
                        <?php endif;?>
                    <?php endforeach;?>
                    <div id="post-type-posts" class="col-12 card-sitemap">
                        <div class="fw-bold lead">Posts</div>
                        <ul class="list-group small">
                            <?php
                            global $post;

                            $posts = get_posts( array(
                                'numberposts'		=> -1,
                                'post_type'			=> 'post',
                                'orderby'			=> 'date',
                                'order'				=> 'DESC',
                            ) );?>

                            <?php foreach ( $posts as $post ) : 
                            setup_postdata( $post );?>
                                <div class="col-4 col-sm-3 col-lg mx-auto">
                                </div>
                                <a class="list-group-item border-top-0 border-bottom-0 border-end-0" title="<?php the_title();?>" href="<?php the_permalink();?>"><?php the_title();?></a>
                            <?php endforeach;
                                wp_reset_postdata();?>
                        </ul>
                        <div class="list-group-item btn btn-sm btn-outline-primary mx-4 card-sitemap sitemap-show" data-toggle="collapse" data-target="#post-type-posts" href="">View All</div>
                    </div>
				</div>
			</div>
			<div class="col-12 col-lg-3 order-lg-1">
				<div id="resourcesMenu" class="sticky-top mb-5 card">
					<div class="accordion small">
						<div class="accordion-item">
							<li class="border-0 accordion-button collapsed" data-toggle="collapse"
								data-target="#toggle-legal">
								<h2 class="small text-uppercase my-2"><strong>Legal</strong></h2>
							</li>
							<div id="toggle-legal" class="collapse" data-parent="#accordion">
								<?php if($privacyPolicy){echo '<a class="privacy d-block list-group-item list-group-item-action border-0 " href="' . $privacyPolicy . '"><i class="fas fa-file-alt px-2"></i> Privacy Policy</a>';};?>
								<?php if($cookie){
								echo '<a class="cookie d-block list-group-item list-group-item-action border-0" href="' . $cookie . '"><i class="fas fa-cookie-bite px-2"></i> Cookie Policy</a>'; };?>
								<?php if($terms){echo '<a class="terms d-block list-group-item list-group-item-action border-0" href="' . $terms . '"><i class="fas fa-gavel px-2"></i> Terms of Service</a>';};?>
							</div>
						</div>
						<hr class="m-0">
						<div class="accordion-item">
							<li class="border-0 accordion-button" data-toggle="collapse"
								data-target="#toggle-resources">
								<h2 class="small text-uppercase my-2"><strong>Resources</strong></h2>
							</li>
							<div id="toggle-resources" class="collapse show" data-parent="#accordion">
								<?php if($sitemap){echo '<a class="sitemap d-block list-group-item list-group-item-action border-0 current" href="' . $sitemap . '"><i class="fas fa-sitemap px-2"></i> Sitemap</a>';};?>
								<?php if($press){echo '<a class="terms d-block list-group-item list-group-item-action border-0" href="' . $press . '"><i class="fas fa-copyright px-2"></i></i>Press</a>';};?>
								<?php if($brand){echo '<a class="terms d-block list-group-item list-group-item-action border-0" href="' . $brand . '"><i class="fas fa-palette px-2"></i></i>Brand</a>';};?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</main>
<?php

get_footer();